<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Block\Adminhtml\System\Config\Fieldset;

use Magento\Store\Model\ScopeInterface;
use Semknox\Semknox\Library\Api\Query\CustomerStatusInterface;
use Semknox\Semknox\Library\Exception\ApiException;
use Semknox\Semknox\Library\Exception\ApiNotAuthenticatedException;
use Semknox\Semknox\Helper\ApiConnection;

/**
 * Fieldset to render API status
 */
class Status extends \Magento\Config\Block\System\Config\Form\Fieldset
{

    /**
     * @var \Semknox\Semknox\Library\UserCredentials
     */
    protected $user;

    /**
     * @var ApiConnection
     */
    protected $apiConnection;

    /**
     * Status constructor.
     *
     * @param \Magento\Backend\Block\Context      $context
     * @param \Magento\Backend\Model\Auth\Session $authSession
     * @param \Magento\Framework\View\Helper\Js   $jsHelper
     * @param ApiConnection                       $apiConnection
     * @param array                               $data
     */
    public function __construct(
        \Magento\Backend\Block\Context $context,
        \Magento\Backend\Model\Auth\Session $authSession,
        \Magento\Framework\View\Helper\Js $jsHelper,
        ApiConnection $apiConnection,
        array $data = []
    ) {
        $this->apiConnection = $apiConnection;

        parent::__construct($context, $authSession, $jsHelper, $data);
    }

    /**
     * Check via API if the user can successfully authenticate.
     *
     * @param int   $storeId
     *
     * @return bool
     */
    protected function apiIsAuthenticated($storeId)
    {
        return $this->apiConnection->isAuthenticated($storeId);
    }

    /**
     * Return header title part of html for payment solution
     *
     * @param \Magento\Framework\Data\Form\Element\AbstractElement $element
     * @return string$context, $data
     * @codeCoverageIgnore
     */
    protected function _getHeaderTitleHtml($element)
    {
        $html = '<div class="config-heading" >';

        if ($element->getContainer()->getParent()->getScope() != ScopeInterface::SCOPE_STORES) {
            $html .= '<div class="message message-info info"><div>' . __('SKNOX_The module has to be configured seperatly for each StoreView.') . '</div></div>';
        } else {
            try {
                if ($this->apiIsAuthenticated($element->getContainer()->getParent()->getScopeId())) {
                    $html .= '<div class="message message-success success"><div>' . __('SKNOX_Successfully connected to the service.') . '</div></div>';
                } else {
                    $html .= '<div class="message message-error error"><div>' . __('SKNOX_Could not connect with the service, please check your credentials.') . '</div></div>';
                }
            } catch (ApiException $exception) {
                $html .= '<div class="message message-warning warning"><div>' . __('SKNOX_There is an error communicating with the server, if this error persists, please contact us!') . '</div></div>';
            }
        }

        $html .= '</div>';

        return $html;
    }

    /**
     * Return header comment part of html
     *
     * @param \Magento\Framework\Data\Form\Element\AbstractElement $element
     * @return string
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     * @codeCoverageIgnore
     */
    protected function _getHeaderCommentHtml($element)
    {
        return '';
    }

    /**
     * Get collapsed state on-load
     *
     * @param \Magento\Framework\Data\Form\Element\AbstractElement $element
     * @return false
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     * @codeCoverageIgnore
     */
    protected function _isCollapseState($element)
    {
        return false;
    }

    /**
     * Don't add default fieldset JS
     *
     * @param \Magento\Framework\Data\Form\Element\AbstractElement $element
     *
     * @return string
     * @codeCoverageIgnore
     */
    protected function _getExtraJs($element)
    {
        return '';
    }
}
