<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */

namespace Semknox\Semknox\Block\Adminhtml\System\Config;

use Magento\Store\Model\ScopeInterface;
use Semknox\Semknox\Helper\ApiConnection;
use Semknox\Semknox\Helper\ConfigInterface;
use Semknox\Semknox\Helper\InitialUpload;
use Semknox\Semknox\Helper\InitialUpload\InfoHelperInterface;

/**
 * Block Upload
 *
 * Upload initial product data backend button, most of the code is borrowed from Core.
 *
 * @package Semknox\Semknox\Block\Adminhtml\System\Config
 *
 * @codeCoverageIgnore      This block is not being tested for now, due to the fact it's basically only rendering
 *                          a template. Might want to consider checking the data array in the future.
 */
class Upload extends \Magento\Config\Block\System\Config\Form\Field
{
    /**
     * @var InitialUpload\InfoHelperFactory
     */
    protected $uploadInfoHelperFactory;

    /**
     * @var ApiConnection
     */
    protected $apiConnection;

    /**
     * @var ConfigInterface
     */
    protected $config;

    /**
     * Upload constructor.
     *
     * @param \Magento\Backend\Block\Template\Context $context
     * @param InitialUpload\InfoHelperFactory         $uploadInfoHelperFactory
     * @param ApiConnection                           $apiConnection
     * @param ConfigInterface                         $config
     * @param array                                   $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        InitialUpload\InfoHelperFactory $uploadInfoHelperFactory,
        ApiConnection $apiConnection,
        ConfigInterface $config,
        array $data = []
    ) {
        parent::__construct($context, $data);

        $this->uploadInfoHelperFactory = $uploadInfoHelperFactory;
        $this->apiConnection = $apiConnection;
        $this->config = $config;
    }

    /**
     * Set template to itself
     *
     * @return Upload
     */
    protected function _prepareLayout()
    {
        parent::_prepareLayout();
        if (!$this->getTemplate()) {
            $this->setTemplate('system/config/upload.phtml');
        }
        return $this;
    }

    /**
     * Unset some non-related element parameters
     *
     * @param \Magento\Framework\Data\Form\Element\AbstractElement $element
     * @return string
     */
    public function render(\Magento\Framework\Data\Form\Element\AbstractElement $element)
    {
        $element->unsCanUseDefaultValue();
        return parent::render($element);
    }

    /**
     * Get the button and scripts contents
     *
     * @param \Magento\Framework\Data\Form\Element\AbstractElement $element
     * @return string
     */
    protected function _getElementHtml(\Magento\Framework\Data\Form\Element\AbstractElement $element)
    {
        if ($element->getScope() == ScopeInterface::SCOPE_STORES) {
            $storeId = $element->getScopeId();
        } else {
            $storeId = $this->_storeManager->getDefaultStoreView()->getStoreGroupId();
        }
        $uploadInfoHelper = $this->uploadInfoHelperFactory->create(['storeId' => $storeId]);

        $this->addData(
            [
            'initial_state' => $uploadInfoHelper->getState(),
            'progress' =>
                $uploadInfoHelper->getState() == InfoHelperInterface::STATE_STOPPED
                    ? 0 : $uploadInfoHelper->getProgress(),
            'button_label' => __('SKNOX_Start Initial Upload'),
            'pause_button_label' => __('SKNOX_Pause Initial Upload'),
            'stop_button_label' => __('SKNOX_Stop Initial Upload'),
            'resume_button_label' => __('SKNOX_Resume Initial Upload'),
            'html_id' => $element->getHtmlId(),
            'ajax_url' => $this->_urlBuilder->getUrl('semknox/system_config/upload'),
            'store_id' => $storeId,
            'authenticated' => $this->apiConnection->isAuthenticated($storeId),
            'disabled' => $this->config->getDataUploadDisabled($storeId)
            ]
        );

        return $this->_toHtml();
    }
}
