<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Artsiom Bruneuski <artsiom.bruneuski@tudock.de>
 */

namespace Semknox\Semknox\Block;

use Magento\Catalog\Model\Layer\Resolver as LayerResolver;
use Magento\CatalogSearch\Helper\Data;
use Magento\Framework\View\Element\Template\Context;
use Magento\Search\Model\QueryFactory;
use Semknox\Semknox\Helper\ApiConnection;

class Result extends \Magento\CatalogSearch\Block\Result
{
    /** @var ApiConnection  */
    protected $apiConnection;

    /**
     * Result constructor.
     * @param Context $context
     * @param LayerResolver $layerResolver
     * @param Data $catalogSearchData
     * @param QueryFactory $queryFactory
     * @param ApiConnection $apiConnection
     * @param array $data
     */
    public function __construct(
        Context $context,
        LayerResolver $layerResolver,
        Data $catalogSearchData,
        QueryFactory $queryFactory,
        ApiConnection $apiConnection,
        array $data = []
    ) {
        $this->apiConnection = $apiConnection;
        parent::__construct($context, $layerResolver, $catalogSearchData, $queryFactory, $data);
    }

    /**
     * Load search result orders by API
     * @return $this
     */
    public function reloadAvailableProductsOrders()
    {
        $availableOrders = [
            'relevance' => __('Relevance')
        ];

        $availableOrders = array_merge(
            $availableOrders,
            $this->apiConnection->getSearchResultOrders()
        );

        $this->getListBlock()->setAvailableOrders(
            $availableOrders
        )->setDefaultDirection(
            'desc'
        )->setDefaultSortBy(
            'relevance'
        );

        return $this;
    }

    /**
     * Return the escape query text
     * @return string
     */
    public function getEscapedQueryText()
    {
        return $this->catalogSearchData->getEscapedQueryText();
    }
}
