<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Artsiom Bruneuski <artsiom.bruneuski@tudock.de>
 */

namespace Semknox\Semknox\Block\Result\ProductList\Item;

use Semknox\Semknox\Helper\ApiConnection;

/**
 * Flag Block for Product Flags in Search.
 * This block provides data for a stub template that will do the actual templating with javascript
 * to avoid the need of overriding the entire product list template.
 */
class Flag extends \Magento\Catalog\Block\Product\ProductList\Item\Block
{

    /**
     * @var ApiConnection
     */
    protected $apiConnection;

    /**
     * Flag constructor.
     *
     * @param \Magento\Catalog\Block\Product\Context $context
     * @param ApiConnection                          $apiConnection
     * @param array                                  $data
     */
    public function __construct(
        \Magento\Catalog\Block\Product\Context $context,
        ApiConnection $apiConnection,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->apiConnection = $apiConnection;
    }

    /**
     * Return the values of the product flag data from the search service as an array containing the flag values
     * (json encoded!)
     * @return string
     */
    public function getProductFlag()
    {
        $flagValues = [];
        if ($this->apiConnection->getSearch() != null) {
            $flagValues = $this->apiConnection->getSearch()->getProductFlag($this->getProduct()->getId());
        }
        return json_encode($flagValues);
    }
}
