<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Artsiom Bruneuski <artsiom.bruneuski@tudock.de>
 */

namespace Semknox\Semknox\Block\Result;

use Semknox\Semknox\Helper\ApiConnection;

class ProductsList extends \Magento\CatalogWidget\Block\Product\ProductsList
{
    /** @var ApiConnection  */
    protected $apiConnection;

    /**
     * ProductsList constructor.
     * @param \Magento\Catalog\Block\Product\Context $context
     * @param \Magento\Catalog\Model\ResourceModel\Product\CollectionFactory $productCollectionFactory
     * @param \Magento\Catalog\Model\Product\Visibility $catalogProductVisibility
     * @param \Magento\Framework\App\Http\Context $httpContext
     * @param \Magento\Rule\Model\Condition\Sql\Builder $sqlBuilder
     * @param \Magento\CatalogWidget\Model\Rule $rule
     * @param \Magento\Widget\Helper\Conditions $conditionsHelper
     * @param ApiConnection $apiConnection
     * @param array $data
     */
    public function __construct(
        \Magento\Catalog\Block\Product\Context $context,
        \Magento\Catalog\Model\ResourceModel\Product\CollectionFactory $productCollectionFactory,
        \Magento\Catalog\Model\Product\Visibility $catalogProductVisibility,
        \Magento\Framework\App\Http\Context $httpContext,
        \Magento\Rule\Model\Condition\Sql\Builder $sqlBuilder,
        \Magento\CatalogWidget\Model\Rule $rule,
        \Magento\Widget\Helper\Conditions $conditionsHelper,
        ApiConnection $apiConnection,
        array $data = []
    ) {
        $this->apiConnection = $apiConnection;
        return parent::__construct(
            $context,
            $productCollectionFactory,
            $catalogProductVisibility,
            $httpContext,
            $sqlBuilder,
            $rule,
            $conditionsHelper,
            $data
        );
    }

    /**
     * Prepare and return product collection
     *
     * @return \Magento\Catalog\Model\ResourceModel\Product\Collection
     */
    public function createCollection()
    {
        if ($this->hasData('product_collection')) {
            return $this->getData('product_collection');
        }
        /** @var $collection \Magento\Catalog\Model\ResourceModel\Product\Collection */
        $collection = $this->productCollectionFactory->create();
        $collection->setVisibility($this->catalogProductVisibility->getVisibleInCatalogIds());

        $collection = $this->_addProductAttributesAndPrices($collection)
            ->addStoreFilter()
            ->setCurPage($this->getRequest()->getParam($this->getData('page_var_name'), 1));

        // Dummy
        $productsIds = [-1];

        if ($this->apiConnection->getSearch()) {
            $zeroResults = $this->apiConnection->getSearch()->getNoResultProductIds();

            if (is_array($zeroResults)) {
                foreach ($zeroResults as $zeroResult) {
                    $productsIds[] = $zeroResult;
                }
            }
        }

        $collection->addFieldToFilter('entity_id', $productsIds);

        $this->setData('product_collection', $collection);
        return $this->getData('product_collection');
    }
}
