<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Artsiom Bruneuski <artsiom.bruneuski@tudock.de>
 */

namespace Semknox\Semknox\Block;

use Magento\Framework\View\Element\Template;
use Psr\Log\LoggerInterface;
use Semknox\Semknox\Helper\ApiConnection;
use Semknox\Semknox\Helper\StateFilter;
use Magento\Catalog\Model\Product\ProductList\Toolbar;
use Magento\CatalogSearch\Helper\Data as CatalogSearchData;

use Semknox\Semknox\Library\Exception\ApiException;

class Search extends Template
{
    /** @var ApiConnection  */
    protected $apiConnection;

    /** @var Toolbar  */
    protected $toolbar;

    /** @var CatalogSearchData  */
    protected $catalogSearchData;

    /** @var StateFilter  */
    protected $stateFilter;

    /** @var \Psr\Log\LoggerInterface */
    protected $logger;

    /**
     * Search constructor.
     * @param Template\Context $context
     * @param ApiConnection $apiConnection
     * @param StateFilter $stateFilter
     * @param Toolbar $toolbar
     * @param CatalogSearchData $catalogSearchData
     * @param array $data
     */
    public function __construct(
        Template\Context $context,
        ApiConnection $apiConnection,
        StateFilter $stateFilter,
        Toolbar $toolbar,
        CatalogSearchData $catalogSearchData,
        array $data = []
    ) {
        $this->apiConnection = $apiConnection;
        $this->stateFilter = $stateFilter;
        $this->toolbar = $toolbar;
        $this->catalogSearchData = $catalogSearchData;
        $this->logger = $context->getLogger();

        $this->_search();

        parent::__construct($context, $data);
    }

    /**
     * Perform search
     * @return void
     */
    protected function _search()
    {
        $filters = $this->stateFilter->getSearchAppliedFilters();
        $rangeFilters = $this->stateFilter->getSearchAppliedRangeFilters();

        $order = $this->apiConnection->convertSearchResultOrder($this->toolbar->getOrder());
        $direction = $this->apiConnection->convertSearchResultDirection($this->toolbar->getDirection());
        if ($this->apiConnection->isOpened()) {
            try {
                $this->apiConnection->search(
                    $this->catalogSearchData->getEscapedQueryText(),
                    $filters,
                    $rangeFilters,
                    $order,
                    $direction
                );
            } catch (ApiException $exception) {
                $this->logger->warning(
                    'Server connection failed (see attached exception).' .
                    'The fallback search engine was used instead.',
                    [
                        'exception' => $exception
                    ]
                );
            }
        }
    }
}
