<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */

namespace Semknox\Semknox\Cron\InitialUpload;

use Magento\Cron\Model\Schedule;
use Magento\Framework\Filesystem\Io\File;
use Semknox\Semknox\Helper\InitialUpload\FileHelper;
use Semknox\Semknox\Helper\InitialUpload\InfoHelper;
use Semknox\Semknox\Helper\InitialUpload\InfoHelperFactory;
use Semknox\Semknox\Helper\InitialUpload\InfoHelperInterface;
use Semknox\Semknox\Service\InitialUpload;

/**
 * Class Runner
 * This cronjob runs the initial upload background process.
 *
 * @package Semknox\Semknox\Cron\InitialUpload
 */
class Runner
{

    /**
     * @var InitialUpload
     */
    protected $initialUpload;

    /**
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    protected $storeManager;

    /**
     * @var InitialUpload
     */
    protected $uploadInfoHelperFactory;

    /**
     * @var File
     */
    protected $ioFile;

    /**
     * @var FileHelper
     */
    protected $fileHelper;

    /**
     * Runner constructor.
     *
     * @param InfoHelperFactory                          $uploadInfoHelperFactory
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param InitialUpload                              $initialUpload
     * @param FileHelper                                 $fileHelper
     * @param File                                       $ioFile
     */
    public function __construct(
        InfoHelperFactory $uploadInfoHelperFactory,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        InitialUpload $initialUpload,
        FileHelper $fileHelper,
        File $ioFile
    ) {
        $this->uploadInfoHelperFactory = $uploadInfoHelperFactory;
        $this->storeManager            = $storeManager;
        $this->initialUpload           = $initialUpload;
        $this->fileHelper              = $fileHelper;
        $this->ioFile                  = $ioFile;
    }

    /**
     * Execute the uploader CRON job.
     * @return void
     */
    public function execute()
    {
        // Make sure only one job is running XXX: Shouldn't Magento only run one job anyway??
        $dir = $this->fileHelper->getDirectory();
        $lockFile = $dir . DIRECTORY_SEPARATOR . 'cron.lock';
        $this->ioFile->checkAndCreateFolder($dir);
        if ($this->ioFile->fileExists($lockFile)) {
            return;
        }
        touch($lockFile);

        try {
            foreach ($this->storeManager->getStores() as $store) {
                $uploadInfoHelper = $this->uploadInfoHelperFactory->create(['storeId' => $store->getId()]);

                if ($uploadInfoHelper->getState() == InfoHelperInterface::STATE_QUEUED ||
                    $uploadInfoHelper->getState() == InfoHelperInterface::STATE_RUNNING
                ) {
                    try {
                        $this->initialUpload->execute($uploadInfoHelper);
                    } catch (\Exception $ex) {
                        $uploadInfoHelper->addException($ex);
                    }
                }
            }
        } finally {
            $this->ioFile->rm($lockFile);
        }
    }
}
