<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */

namespace Semknox\Semknox\Cron\InitialUpload;

use Semknox\Semknox\Helper\ConfigInterface;
use Semknox\Semknox\Helper\InitialUpload\InfoHelperInterface;
use Semknox\Semknox\Helper\InitialUpload\Logger;
use Semknox\Semknox\Service\InitialUpload;
use Semknox\Semknox\Helper\InitialUpload\InfoHelperFactory;

/**
 * Class Scheduled
 * Starts the full upload process, if the "full upload strategy"
 * is enabled for the store. Chcked nightly for every store.
 *
 * @package Semknox\Semknox\Cron\InitialUpload
 */
class Scheduled
{

    /**
     * @var InitialUpload
     */
    protected $initialUpload;

    /**
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    protected $storeManager;

    /**
     * @var InitialUpload
     */
    protected $uploadInfoHelperFactory;

    /**
     * @var ConfigInterface
     */
    protected $config;

    /**
     * @var Logger
     */
    protected $logger;

    /**
     * Runner constructor.
     *
     * @param InfoHelperFactory                          $uploadInfoHelperFactory
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param InitialUpload                              $initialUpload
     * @param ConfigInterface                            $config
     * @param Logger                                     $logger
     */
    public function __construct(
        InfoHelperFactory $uploadInfoHelperFactory,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        InitialUpload $initialUpload,
        ConfigInterface $config,
        Logger $logger
    ) {
        $this->uploadInfoHelperFactory = $uploadInfoHelperFactory;
        $this->storeManager            = $storeManager;
        $this->initialUpload           = $initialUpload;
        $this->config                  = $config;
        $this->logger                  = $logger;
    }

    /**
     * Start full upload for all stores that use "full upload strategy"
     * Does NOT actually run the upload process, the "Runner" deals with that
     * @return void
     */
    public function execute()
    {
        foreach ($this->storeManager->getStores() as $store) {
            if (// Only schedule if "full upload strategy" is selected
                $this->config->getFullUploadStrategy($store->getId())
            ) {
                /** @var InfoHelperInterface $uploadInfoHelper */
                $uploadInfoHelper = $this->uploadInfoHelperFactory->create(['storeId' => $store->getId()]);
                if ($uploadInfoHelper->getState() == InfoHelperInterface::STATE_STOPPED ||
                    $uploadInfoHelper->getState() == InfoHelperInterface::STATE_PAUSED
                ) {
                    $uploadInfoHelper->setState(InfoHelperInterface::STATE_QUEUED);
                    $uploadInfoHelper->clearExceptions();
                    $this->logger->info(
                        'Product Indexer: Full daily product upload scheduled for '.
                        $store->getId().' due to active "full upload" strategy...',
                        $uploadInfoHelper
                    );
                }
            }
        }
    }
}
