<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */

namespace Semknox\Semknox\Helper;

/**
 * Interface ConfigInterface
 *
 * This interface contains COMMON configuration values and is the only way this module should use the configuration!
 * It may be extended by the library modules.
 *
 * @package Semknox\Semknox\Helper
 */
interface ConfigInterface
{
    /**
     * Is the options for SEO URLs currently enabled?
     *
     * @param int $storeId  Optional, explicitly set the store to get the settings from
     *
     * @return bool
     */
    public function getSeoUrlEnabled($storeId = null);

    /**
     * Get the prefix to be used for SEO urls (bla ==> /bla-my-search)
     *
     * @param int $storeId  Optional, explicitly set the store to get the settings from
     *
     * @return string
     */
    public function getSeoUrlPrefix($storeId = null);

    /**
     * Get the noroute. Format: route/controller/action
     *
     * @param int $storeId  Optional, explicitly set the store to get the settings from
     *
     * @return string
     */
    public function getNoRoute($storeId = null);

    /**
     * Check whether the product upload is enabled or not
     *
     * @param int $storeId  Optional, explicitly set the store to get the settings from
     *
     * @return bool
     */
    public function getDataUploadDisabled($storeId = null);

    /**
     * If false:
     * - Use indexer to process partial product updates
     * If true:
     * - The indexer does nothing
     * - Schedule a full product upload every night
     *
     * @param int $storeId  Optional, explicitly set the store to get the settings from
     *
     * @return bool
     */
    public function getFullUploadStrategy($storeId = null);

    /**
     * Whether the meta-robots tag für CatalogSearch result pages is set to:
     * (true) => INDEX,FOLLOW
     * (false) => NOINDEX, NOFOLLOW
     *
     * @param int $storeId  Optional, explicitly set the store to get the settings from
     *
     * @return mixed
     */
    public function getAreRobotsAllowedOnSearchResults($storeId = null);

    /**
     * Dump the configuration needed for the LibAuthenticationInterface
     * implementation. The actual needed configuration depends on the library used.
     * @see \Semknox\Semknox\Library\LibAuthenticationInterface::setConfiguration
     *
     * @param int $storeId  Optional, explicitly set the store to get the settings from
     *
     * @return array
     */
    public function dumpConfigurationForLibrary($storeId = null);
}
