<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Helper\InitialUpload;

use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\Filesystem\Io\File;

/**
 * Class FileHelper
 *
 * Simple helper to have a central place to get the path information for the upload process from
 *
 * @package Semknox\Semknox\Helper\InitialUpload
 */
class FileHelper
{

    /**
     * @var DirectoryList
     */
    protected $directoryList;

    /**
     * @var string
     */
    protected $dir;

    /**
     * @var string
     */
    protected $dataFilePrefix;

    /**
     * @var File
     */
    protected $ioFile;

    /**
     * FileHelper constructor.
     *
     * @param DirectoryList $directoryList
     * @param File          $ioFile
     */
    public function __construct(
        DirectoryList $directoryList,
        File $ioFile
    ) {
        $this->directoryList = $directoryList;
        $this->ioFile = $ioFile;

        $this->dir = $this->directoryList->getPath(DirectoryList::VAR_DIR) . DIRECTORY_SEPARATOR . 'semknox';
        $this->dataFilePrefix = 'running-upload-data-store';
    }

    /**
     * Path of the initial upload directory
     * @return string
     */
    public function getDirectory()
    {
        return $this->dir;
    }

    /**
     * Path of a subdirectory for a given process
     *
     * @param string $process
     *
     * @return string
     */
    public function getDirectoryFor($process)
    {
        return $this->dir . DIRECTORY_SEPARATOR . $process;
    }

    /**
     * Format the full path to an upload file.
     *
     * @param string $process
     * @param int    $storeId
     * @param int    $fileBatchId
     *
     * @return string
     */
    public function getFileName($process, $storeId, $fileBatchId)
    {
        $dir = $this->getDirectoryFor($process);
        return $dir . DIRECTORY_SEPARATOR . $this->dataFilePrefix . $storeId . '-' . $fileBatchId . '.json';
    }

    /**
     * Recreate the directory of a process
     *
     * @param string $process
     *
     * @return void
     */
    public function resetDirectoryFor($process)
    {
        $dir = $this->getDirectoryFor($process);
        // If first batch, recreate the export directory
        if ($this->ioFile->fileExists($dir, false)) {
            if (!$this->ioFile->rmdir($dir)) {
                // Removing the directory failed. Fall back to unlink
                array_map('unlink', glob($dir . DIRECTORY_SEPARATOR ."*.json"));
            }
        }
        $this->ioFile->checkAndCreateFolder($dir, 0775);
    }
}
