<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Helper\InitialUpload;

/**
 * InfoHelper Interface
 *
 * Helper class for retreiving current state and other misc. information
 * about the initial upload process
 *
 * @package Semknox\Semknox\Helper
 */
interface InfoHelperInterface
{

    const STATE_PAUSED = 'paused';
    const STATE_STOPPED = 'stopped';
    const STATE_QUEUED = 'queued';
    const RUNNER_WAITING = 'runner_waiting';
    const RUNNER_READY_FOR_UPLOAD = 'runner_ready_upload';
    const RUNNER_COLLECTING = 'runner_collection';
    const STATE_RUNNING = 'running';

    /**
     * Reload the flag data.
     * @return void
     */
    public function refreshFlagData();

    /**
     * @return int
     */
    public function getStoreId();

    /**
     * Return the current flag code
     *
     * If the flag code got corrupted somehow (or isn't set yet), returns the STATE_STOPPED code.
     *
     * @return string returns a value from the state variables
     */
    public function getState();

    /**
     * Set the flag code, setting the value to anything other than
     * the constants of this class will thrown an exception.
     *
     * @param string    $flagCode
     * @return void
     */
    public function setState($flagCode);

    /**
     * Get the interruptable state.
     * @return bool
     */
    public function isInterruptable();

    /**
     * Set the interruptable state.
     *
     * @param boolean $interruptable
     * @return void
     */
    public function setInterruptable($interruptable);

    /**
     * Get the progress.
     * @return int
     */
    public function getProgress();

    /**
     * Set the progress.
     *
     * @param number $progress
     * @return void
     */
    public function setProgress($progress);

    /**
     * Get last success.
     * @return \DateTime
     */
    public function getLastSuccess();

    /**
     * Set last success
     *
     * @param \DateTime $lastSuccess
     * @return void
     */
    public function setLastSuccess(\DateTime $lastSuccess);

    /**
     * Get the batch id.
     * @return int
     */
    public function getBatch();

    /**
     * Set the batch id
     *
     * @param number $batch
     * @return void
     */
    public function setBatch($batch);

    /**
     * Get the runner state.
     * @return string
     */
    public function getRunnerState();

    /**
     * Set the runner state
     *
     * @param string $runnerState
     * @return void
     */
    public function setRunnerState($runnerState);

    /**
     * Resets all upload related flags to a point that represents the initial state of the process.
     * This does however not modify the overall state flag.
     * @return void
     */
    public function setToInitial();

    /**
     * Adds an exception to the upload state.
     * On the third added exception an upload process is stopped.
     *
     * @param \Exception $exception
     */
    public function addException($exception);

    /**
     * Clears all exceptions of the upload state and resets the exception counter to zero.
     */
    public function clearExceptions();

    /**
     * Get's the exceptions from this run.
     * @return array [['trace' => string, 'message' => string]]
     */
    public function getExceptions();
}
