<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */

namespace Semknox\Semknox\Helper\InitialUpload;

class Logger
{

    /**
     * Enable verbose debug logging
     */
    const DEBUG_ENABLED = true;

    /**
     * @var \Psr\Log\LoggerInterface
     */
    protected $logger;

    /**
     * Logger constructor.
     *
     * @param \Psr\Log\LoggerInterface $logger
     */
    public function __construct(\Psr\Log\LoggerInterface $logger)
    {
        $this->logger = $logger;
    }

    /**
     * @param string              $message
     * @param InfoHelperInterface $uploadInfoHelper The store specific flag helper
     * @return void
     */
    public function info($message, $uploadInfoHelper)
    {
        $this->log($message, \Monolog\Logger::INFO, $uploadInfoHelper);
    }

    /**
     * @param string              $message
     * @param InfoHelperInterface $uploadInfoHelper The store specific flag helper
     * @return void
     */
    public function error($message, $uploadInfoHelper)
    {
        $this->log($message, \Monolog\Logger::ERROR, $uploadInfoHelper);
    }

    /**
     * @param string              $message
     * @param InfoHelperInterface $uploadInfoHelper The store specific flag helper
     * @return void
     */
    public function debug($message, $uploadInfoHelper)
    {
        if (!self::DEBUG_ENABLED) {
            return;
        }
        $this->log($message, \Monolog\Logger::DEBUG, $uploadInfoHelper);
    }

    /**
     * @param string              $message
     * @param mixed               $level
     * @param InfoHelperInterface $uploadInfoHelper The store specific flag helper
     * @return void
     */
    protected function log($message, $level, $uploadInfoHelper)
    {
        $this->logger->log(
            $level,
            'SKNOX Upload [PID '.getmypid().' | Store '.$uploadInfoHelper->getStoreId().']: '.$message,
            [
                'process' => 'SEMKNOX Initial Upload',
                'state' => $uploadInfoHelper->getState(),
                'runnerState' => $uploadInfoHelper->getRunnerState(),
                'interruptable' => $uploadInfoHelper->isInterruptable(),
                'batch' => $uploadInfoHelper->getBatch(),
                'progress' => $uploadInfoHelper->getProgress(),
                'storeId' => $uploadInfoHelper->getStoreId()
            ]
        );
    }
}
