<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Artsiom Bruneuski <artsiom.bruneuski@tudock.de>
 */

namespace Semknox\Semknox\Helper;

use Magento\Framework\App\Helper\Context;
use Magento\Framework\Stdlib\StringUtils;
use Semknox\Semknox\Library\Api\Data\Result\FilterInterface;
use Semknox\Semknox\Library\SearchResult\LibFilterInterface;

class StateFilter extends \Magento\Framework\App\Helper\AbstractHelper
{
    const SEARCH_REQUEST_PARAM = 'semknox_default';
    const SEARCH_REQUEST_RANGE_PARAM = 'semknox_range';
    const SEARCH_REQUEST_PARAM_DELIMITER = '|';

    /**
     * @var StringUtils
     */
    protected $stringUtils;

    /**
     * StateFilter constructor.
     *
     * @param Context     $context
     * @param StringUtils $stringUtils
     */
    public function __construct(
        Context $context,
        StringUtils $stringUtils
    ) {
        $this->stringUtils = $stringUtils;
        parent::__construct($context);
    }

    /**
     * @param string $requestVar
     *
     * @return array
     */
    public function getSearchAppliedFilters($requestVar = self::SEARCH_REQUEST_PARAM)
    {
        $filters = null;
        $params = $this->_getRequest()->getParams();

        foreach ($params as $key => $value) {
            // Skip empty values
            if (!$value || $value == '') {
                continue;
            }
            if ($this->stringUtils->strpos($key, $requestVar) !== false) {
                if ($filters === null) {
                    $filters = [];
                }

                list($prefix, $filterId) = explode(self::SEARCH_REQUEST_PARAM_DELIMITER, urldecode($key));

                if (!array_key_exists($filterId, $filters)) {
                    $filters[$filterId] = [];
                }
                $filters[$filterId] = array_unique(explode(',', $value));
            }
        }

        return $filters;
    }

    /**
     * @param string $requestVar
     * @return array
     */
    public function getSearchAppliedRangeFilters($requestVar = self::SEARCH_REQUEST_RANGE_PARAM)
    {
        $filters = $this->getSearchAppliedFilters($requestVar);
        return $filters;
    }

    /**
     * @param LibFilterInterface $filter
     * @return array|mixed
     */
    public function getSearchAppliedFilter(LibFilterInterface $filter)
    {
        $optionVals = [];

        $appliedFilters = $this->getSearchAppliedFilters();
        if ($appliedFilters && array_key_exists($filter->getId(), $appliedFilters)) {
            $optionVals = $appliedFilters[$filter->getId()];
        }

        return $optionVals;
    }

    /**
     * @param LibFilterInterface $filter
     * @return array|mixed
     */
    public function getSearchAppliedRangeFilter(LibFilterInterface $filter)
    {
        $optionVals = [];

        $appliedFilters = $this->getSearchAppliedRangeFilters();
        if ($appliedFilters && array_key_exists($filter->getId(), $appliedFilters)) {
            $optionVals = $appliedFilters[$filter->getId()];
        }

        return $optionVals;
    }
}
