<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Library\Exception;

use Exception;

/**
 * Class ApiException
 *
 * A generic API error to be thrown if the API returns an unknown error.
 * Please use subclasses to further specify the type of error
 *
 * @package Semknox\Semknox\Library\Exception
 */
class ApiException extends \Exception
{

    /**
     * The response from the server, if any
     * @var string
     */
    protected $responseBody;

    /**
     * ApiException constructor.
     *
     * @param string         $message
     * @param string         $responseBody
     * @param int            $code
     * @param Exception|null $previous
     */
    public function __construct($message = "", $responseBody = "", $code = 0, Exception $previous = null)
    {
        $this->responseBody = $responseBody;
        parent::__construct($message, $code, $previous);
    }

    /**
     * The body of the original result. May be empty if n/a.
     * @codeCoverageIgnore
     * @return string
     */
    public function getResponseBody()
    {
        return $this->responseBody;
    }
}
