<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Library;

use Semknox\Semknox\Library\Exception\ApiException;
use Semknox\Semknox\Library\Exception\ApiNotAuthenticatedException;
use Semknox\Semknox\Library\LibAuthenticationInterface;
use Semknox\Semknox\Library\Semknox\SemknoxApi;

/**
 * Library interface that handles user authentication and server information
 *
 * @package Semknox\Semknox\Library
 */
class LibAuthentication implements LibAuthenticationInterface
{

    /**
     * @type SemknoxApi
     */
    protected $semknoxApi;

    /**
     * LibAuthentication constructor.
     *
     * @param SemknoxApi $semknoxApi
     */
    public function __construct(
        SemknoxApi $semknoxApi
    ) {
        $this->semknoxApi = $semknoxApi;
    }

    /**
     * Set the required authentication/connection configuration.
     * The input is an associative array.
     * The fields of the array depend on the actual library being used,
     * as a hint getConfigurationFields can be used to retrieve the fields that need to be set
     *
     * @param array $configData
     *
     * @return void
     * @throws ApiException
     */
    public function setConfiguration($configData)
    {
        if (!array_key_exists('customer_id', $configData) || !array_key_exists('api_key', $configData) || !array_key_exists('api_url', $configData)) {
            throw new ApiException('Customer ID, API key or API url missing from configuration settings');
        }

        $this->semknoxApi->getApiConfig()->setCustomerId($configData['customer_id']);
        $this->semknoxApi->getApiConfig()->setApiKey($configData['api_key']);
        $this->semknoxApi->getApiConfig()->setApiUrl($configData['api_url']);
        $this->semknoxApi->getApiConfig()->setSearchBatchSize($configData['search_batch_size']);
    }

    /**
     * Returns an array of strings containing the field names required by setConfiguration.
     * This may or may not be used to automatically provide configuration fields in the backend.
     * It is not used by the main module Semknox_Semknox as of August 2017.
     *
     * @return string[]
     */
    public function getConfigurationFields()
    {
        return ['customer_id', 'api_key', 'api_url', 'search_batch_size'];
    }

    public function testConnection()
    {
        // Don't test if customer id or API key is not set
        if (!$this->semknoxApi->getApiConfig()->getCustomerId() || !$this->semknoxApi->getApiConfig()->getApiKey()) {
            throw new ApiNotAuthenticatedException('No API Key or Customer ID set');
        }
        $this->semknoxApi->getCustomerStatus()->testConnection();
        return true;
    }
}
