<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Library;

use Semknox\Semknox\Library\Exception\ApiException;
use Semknox\Semknox\Library\Exception\ApiNotAuthenticatedException;

/**
 * Interface LibAuthenticationInterface
 *
 * Library interface that handles user authentication and server information
 *
 * @package Semknox\Semknox\Library
 */
interface LibAuthenticationInterface
{
    /**
     * Set the required authentication/connection configuration.
     * The input is an associative array.
     * The fields of the array depend on the actual library being used,
     * as a hint getConfigurationFields can be used to retrieve the fields that need to be set
     *
     * @param array $configData
     *
     * @return void
     */
    public function setConfiguration($configData);

    /**
     * Returns an array of strings containing the field names required by setConfiguration.
     * This may or may not be used to automatically provide configuration fields in the backend.
     * It is not used by the main module Semknox_Semknox as of August 2017.
     *
     * @return string[]
     */
    public function getConfigurationFields();

    /**
     * Tests if the connection is successful.
     * If no exception is thrown the connection was successful.
     *
     * @return boolean
     * @throws ApiNotAuthenticatedException The authentication information seems to be incorrect.
     * @throws ApiException A general error occurred.
     */
    public function testConnection();
}
