<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Library;

use Semknox\Semknox\Library\LibAuthenticationInterface;
use Semknox\Semknox\Library\LibEntrypointInterface;
use Semknox\Semknox\Library\LibFeaturesInterface;
use Semknox\Semknox\Library\LibSearchInterface;
use Semknox\Semknox\Library\LibUpdateInterface;
use Semknox\Semknox\Library\Semknox\SemknoxApi;
use Semknox\Semknox\Library\Semknox\SemknoxApiFactory;

/**
 * The entrypoint class for library communication that grants access to other functionality interfaces
 *
 * @package Semknox\Semknox\Library
 */
class LibEntrypoint implements LibEntrypointInterface
{

    /**
     * @var LibAuthenticationInterface
     */
    protected $auth;

    /**
     * @var LibFeaturesInterface
     */
    protected $features;

    /**
     * @var LibSearchInterface
     */
    protected $search;

    /**
     * @var LibUpdateInterface
     */
    protected $update;

    /**
     * @var SemknoxApi
     */
    protected $semknoxApi;

    /**
     * LibEntrypoint constructor.
     *
     * @param SemknoxApiFactory          $semknoxApiFactory
     * @param LibAuthenticationFactory $libAuthenticationFactory
     * @param LibFeaturesFactory         $libFeaturesFactory
     * @param LibSearchFactory           $libSearchFactory
     * @param LibUpdateFactory           $libUpdateFactory
     */
    public function __construct(
        SemknoxApiFactory $semknoxApiFactory,
        LibAuthenticationFactory $libAuthenticationFactory,
        LibFeaturesFactory $libFeaturesFactory,
        LibSearchFactory $libSearchFactory,
        LibUpdateFactory $libUpdateFactory
    ) {
        $this->semknoxApi = $semknoxApiFactory->create();
        $this->auth = $libAuthenticationFactory->create([
            'semknoxApi' => $this->semknoxApi
        ]);
        $this->features = $libFeaturesFactory->create([
            'semknoxApi' => $this->semknoxApi
        ]);
        $this->search = $libSearchFactory->create([
            'semknoxApi' => $this->semknoxApi
        ]);
        $this->update = $libUpdateFactory->create([
            'semknoxApi' => $this->semknoxApi
        ]);
    }

    /**
     * @return LibAuthenticationInterface
     */
    public function auth()
    {
        return $this->auth;
    }

    /**
     * @return LibFeaturesInterface
     */
    public function features()
    {
        return $this->features;
    }

    /**
     * @return LibSearchInterface
     */
    public function search()
    {
        return $this->search;
    }

    /**
     * @return LibUpdateInterface
     */
    public function update()
    {
        return $this->update;
    }

    /**
     * Raw API access for lib specific API calls.
     */
    public function semknoxApi()
    {
        return $this->semknoxApi;
    }
}
