<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Library;

use Semknox\Semknox\Library\LibSearchInterface;
use Semknox\Semknox\Library\SearchResult\LibSearchResultInterface;
use Semknox\Semknox\Library\SearchResult\LibSearchResultFactory;
use Semknox\Semknox\Library\Semknox\ApiCommunicator;
use Semknox\Semknox\Library\Semknox\SemknoxApi;

class LibSearch implements LibSearchInterface
{

    /**
     * @type SemknoxApi
     */
    protected $semknoxApi;

    /**
     * @var LibSearchResultFactory
     */
    protected $libSearchResultFactory;

    /**
     * LibAuthentication constructor.
     *
     * @param SemknoxApi $semknoxApi
     */
    public function __construct(
        SemknoxApi $semknoxApi,
        LibSearchResultFactory $libSearchResultFactory
    ) {
        $this->semknoxApi = $semknoxApi;
        $this->libSearchResultFactory = $libSearchResultFactory;
    }

    /**
     * @param $query
     * @param $filters
     * @param $rangeFilters
     * @param $order
     * @param $dir
     *
     * @return LibSearchResultInterface
     */
    public function getProducts($query, $filters, $rangeFilters, $order, $dir)
    {
        return $this->libSearchResultFactory->create(['products' =>
            $this->semknoxApi->getProducts($query, $filters, $rangeFilters, $order, $dir)
        ]);
    }

    /**
     * Parameters used by the JavaScript frontend search box, used for directly calling the API.
     *
     * Returns a map (array)
     * Must contain a field "source" that includes the URL to the endpoint (whole URL). All other fields are optional
     * and will be sent in a get request
     *
     * @return array
     */
    public function getSuggestFrontendParams()
    {
        return [
            'source' => $this->semknoxApi->getApiConfig()->getApiUrl() . 'queries/semanticSuggest',
            'customerId' => $this->semknoxApi->getApiConfig()->getCustomerId(),
            'apiKey' => $this->semknoxApi->getApiConfig()->getPublicApiKey()
        ];
    }
}
