<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Library;

use Semknox\Semknox\Library\SearchResult\LibSearchResultInterface;

interface LibSearchInterface
{

    /**
     * Perform a search and return the result
     *
     * @param string $query         The input query entered by the user
     * @param array  $filters       An array of filters, where keys
     *                              are SSP-specific attribute keys, values are an array of values
     *                              null if no filters were specified
     * @param array  $rangeFilters  An array of ranged filters, where keys
     *                              are SSP-specific attribute keys,
     *                              null if no ranged filters were specified
     *                              value is an array where first value is min, second is max
     * @param string $order         The SSP-specific attribute key to order by
     *                              null if no order was specified
     * @param string $dir           The SSP-specific sort direction (usally the strings ASC or DESC)
     *
     * @return LibSearchResultInterface
     */
    public function getProducts($query, $filters, $rangeFilters, $order, $dir);

    /**
     * Parameters used by the JavaScript frontend search box, used for directly calling the API.
     *
     * Returns a map (array)
     * Must contain a field "source" that includes the URL to the endpoint (whole URL). All other fields are optional
     * and will be sent in a get request
     *
     * @return array
     */
    public function getSuggestFrontendParams();
}
