<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Library;

use Semknox\Semknox\Library\LibUpdateInterface;
use Semknox\Semknox\Library\Semknox\SemknoxApi;

class LibUpdate implements LibUpdateInterface
{
    /**
     * @type SemknoxApi
     */
    protected $semknoxApi;

    /**
     * LibAuthentication constructor.
     *
     * @param SemknoxApi $semknoxApi
     */
    public function __construct(
        SemknoxApi $semknoxApi
    ) {
        $this->semknoxApi = $semknoxApi;
    }

    /**
     * Add a single product using an array
     *
     * @param array $productsArray An array of product data, according to the API specification.
     *
     * @api
     *
     * @return void
     */
    public function addProducts($productsArray)
    {
        $this->semknoxApi->putProducts()->addProducts($productsArray);
    }

    /**
     * Add a single product using JSON data
     *
     * @param string $jsonProductData JSON encoded product data, according to the API specification.
     *
     * @api
     *
     * @return void
     */
    public function addProductsByJson($jsonProductData)
    {
        $this->semknoxApi->putProducts()->addProductsByJson($jsonProductData);
    }

    /**
     * Delete a single product
     *
     * @param int $articleNumber
     *
     * @return void
     */
    public function deleteProduct($articleNumber)
    {
        $this->semknoxApi->deleteProducts()->delete($articleNumber);
    }

    /**
     * Signal the beginning of a full product upload, where all products will be replaced by
     * the products added by @see replaceProductsAdd.
     *
     * End the process using @see replaceProductsCommit.
     *
     * @return void
     */
    public function replaceProductsBegin()
    {
        $this->semknoxApi->putProductsBatch()->clearInput();
    }

    /**
     * Add Products to the full product upload process, that was initiated using @see replaceProductsBegin
     *
     * End the process using @see replaceProductsCommit.
     *
     * @param array $productsArray An array of product data, according to the API specification.
     *
     * @return void
     */
    public function replaceProductsAdd($productsArray)
    {
        $this->semknoxApi->putProductsBatch()->batchInput($productsArray);
    }

    /**
     * Add Products to the full product upload process, that was initiated using @see replaceProductsBegin
     *
     * End the process using @see replaceProductsCommit.
     *
     * @param string $jsonProductData JSON encoded product data, according to the API specification.
     *
     * @return void
     */
    public function replaceProductsAddByJson($jsonProductData)
    {
        $this->semknoxApi->putProductsBatch()->batchInputByJson($jsonProductData);
    }

    /**
     * Commit the products added to the running full data upload, started by @see replaceProductsBegin.
     *
     * @return void
     */
    public function replaceProductsCommit()
    {
        $this->semknoxApi->putProductsBatch()->fullUpdate();
    }
}
