<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Library;

interface LibUpdateInterface
{

    /**
     * Add a single product using an array
     *
     * @param array $productsArray An array of product data, according to the API specification.
     *
     * @api
     *
     * @return void
     */
    public function addProducts($productsArray);

    /**
     * Add a single product using JSON data
     *
     * @param string $jsonProductData JSON encoded product data, according to the API specification.
     *
     * @api
     *
     * @return void
     */
    public function addProductsByJson($jsonProductData);

    /**
     * Signal the beginning of a full product upload, where all products will be replaced by
     * the products added by @see replaceProductsAdd.
     *
     * End the process using @see replaceProductsCommit.
     *
     * @api
     *
     * @return void
     */
    public function replaceProductsBegin();

    /**
     * Add Products to the full product upload process, that was initiated using @see replaceProductsBegin
     *
     * End the process using @see replaceProductsCommit.
     *
     * @param array $productsArray An array of product data, according to the API specification.
     *
     * @api
     *
     * @return void
     */
    public function replaceProductsAdd($productsArray);

    /**
     * Add Products to the full product upload process, that was initiated using @see replaceProductsBegin
     *
     * End the process using @see replaceProductsCommit.
     *
     * @param string $jsonProductData JSON encoded product data, according to the API specification.
     *
     * @api
     *
     * @return void
     */
    public function replaceProductsAddByJson($jsonProductData);

    /**
     * Commit the products added to the running full data upload, started by @see replaceProductsBegin.
     *
     * @return void
     */
    public function replaceProductsCommit();

    /**
     * Delete a single product
     *
     * @param int $articleNumber
     *
     * @api
     *
     * @return void
     */
    public function deleteProduct($articleNumber);
}
