<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Library\SearchResult;

/**
 * Class LibFilter
 *
 * Default implementations, implements this as a simple data object
 *
 * @package Semknox\Semknox\Library\SearchResult
 */
class LibFilter implements LibFilterInterface
{

    /**
     * @var string
     */
    protected $type;

    /**
     * @var string
     */
    protected $name;

    /**
     * @var mixed
     */
    protected $id;

    /**
     * @var LibFilterOptionInterface[]
     */
    protected $options;

    /**
     * @var int
     */
    protected $max;

    /**
     * @var int
     */
    protected $min;

    /**
     * @var string
     */
    protected $unitName;

    /**
     * Get type of filter, which may be any of the FILTER_TYPE_* constants
     *
     * @return mixed
     */
    public function getType()
    {
        return $this->type;
    }

    /**
     * Human-readable name of this filter attribute
     *
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Identifier / Attribute Code / Field Name of this filter
     *
     * @return mixed
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * A list of possible options for this filter
     *
     * @return LibFilterOptionInterface[]
     */
    public function getOptions()
    {
        return $this->options;
    }

    /**
     * Only if range filter:
     * Maximum value
     *
     * @return mixed
     */
    public function getMax()
    {
        return $this->max;
    }

    /**
     * Only if range filter:
     * Minimum value
     *
     * @return mixed
     */
    public function getMin()
    {
        return $this->min;
    }

    /**
     * Only if range filter:
     * Name of the unit controlled by this range filter
     *
     * @return mixed
     */
    public function getUnitName()
    {
        return $this->unitName;
    }

    /**
     * @param string $type
     * @return void
     */
    public function setType($type)
    {
        $this->type = $type;
    }

    /**
     * @param string $name
     * @return void
     */
    public function setName($name)
    {
        $this->name = $name;
    }

    /**
     * @param mixed $id
     * @return void
     */
    public function setId($id)
    {
        $this->id = $id;
    }

    /**
     * @param LibFilterOptionInterface[] $options
     * @return void
     */
    public function setOptions($options)
    {
        $this->options = $options;
    }

    /**
     * @param int $max
     * @return void
     */
    public function setMax($max)
    {
        $this->max = $max;
    }

    /**
     * @param int $min
     * @return void
     */
    public function setMin($min)
    {
        $this->min = $min;
    }

    /**
     * @param string $unitName
     * @return void
     */
    public function setUnitName($unitName)
    {
        $this->unitName = $unitName;
    }
}
