<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Library\SearchResult;

interface LibSearchResultInterface
{

    /**
     * Returns the ids of all products found by this search
     * Returns empty array if no products were found
     *
     * @return int[]
     */
    public function getResultProductIds();

    /**
     * If no products were found and this library supports "suggested products on no search result"
     * this may return an array of product ids to show.
     * Otherwise this will return an empty array
     *
     * @return int[]
     */
    public function getNoResultProductIds();

    /**
     * Returns the product flags (array of string to show on top of product image in product list)
     * for the given product if
     * 1. the library supports product flags
     * 2. the product was in the search results and has a flag
     *
     * Otherwise returns empty array
     *
     * @param int $productId
     *
     * @return string[]
     */
    public function getProductFlag($productId);

    /**
     * Return the available filters that can be performed on this search query
     *
     * @return LibFilterInterface[]
     */
    public function getFilters();

    /**
     * Additional orders / sortings resulting from this search.
     * May return empty array if the library does not support this feature.
     *
     * @return array Array in the form  ['id' => <Identifier of order>, 'name' => <human readable name>]
     */
    public function getOrders();
}
