<?php
/**
 * SEMKNOX API - PHP Library
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Library\Semknox\Query;

use Semknox\Semknox\Library\Exception\ApiException;
use Semknox\Semknox\Library\Exception\ApiNotAuthenticatedException;
use Semknox\Semknox\Library\Semknox\ApiCommunicator;

/**
 * Class CustomerStatus
 *
 * Get information of the current customer.
 *
 * @package Semknox\Semknox\Library\Query
 */
class CustomerStatus
{

    /**
     * Cached response array
     * @var array
     */
    protected $response;

    /**
     * @var ApiCommunicator
     */
    protected $api;

    /**
     * CustomerStatus constructor.
     *
     * @param ApiCommunicator $apiCommunicator
     */
    public function __construct(
        ApiCommunicator $apiCommunicator
    ) {
        $this->api = $apiCommunicator;
    }

    /**
     * Customer name
     *
     * @return string
     * @api
     */
    public function getCustomerName()
    {
        return $this->query('customerName');
    }

    /**
     * Customer id
     *
     * @return int
     * @api
     */
    public function getCustomerId()
    {
        return $this->query('customerId');
    }

    /**
     * Update Progress (0-1)
     *
     * @return float
     * @api
     */
    public function getUpdateProgress()
    {
        return $this->query('updateProgress');
    }

    /**
     * Valid Through
     *
     * @return int
     * @api
     */
    public function getValidThrough()
    {
        return $this->query('validThrough');
    }

    /**
     * Only perfom the request to test the connection,
     * may throw the ApiExceptions if an error occurs,
     * if no exception was thrown the request was successful.
     * @return void
     * @api
     * @throws ApiException
     * @throws ApiNotAuthenticatedException
     */
    public function testConnection()
    {
        $this->getCustomerName();
    }

    /**
     * Perform the requested query and return the result.
     *
     * @param string $fieldName
     *
     * @return mixed
     */
    protected function query($fieldName)
    {
        if (!$this->response) {
            $this->response = $this->api->requestGet('customers/:customerId/status');
        }
        return $this->response[$fieldName];
    }
}
