<?php
/**
 * SEMKNOX API - PHP Library
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Library\Semknox\Query;

use Semknox\Semknox\Library\Semknox\ApiCommunicator;

/**
 * Class ProductsPut
 *
 * Update the products
 *
 * @package Semknox\Semknox\Library\Query
 */
class ProductsPut
{

    /**
     * @var ApiCommunicator
     */
    protected $api;

    /**
     * ProductsPut constructor.
     *
     * @param ApiCommunicator $apiCommunicator
     */
    public function __construct(
        ApiCommunicator $apiCommunicator
    ) {
        $this->api = $apiCommunicator;
    }

    /**
     * Add a single product using an array
     *
     * @param array $productsArray An array of product data, according to the API specification.
     *
     * @api
     *
     * @return void
     */
    public function addProducts($productsArray)
    {
        $this->uploadProducts(json_encode($productsArray), false);
    }

    /**
     * Replace all products by the provided products using an array
     *
     * @param array $productsArray An array of product data, according to the API specification.
     *
     * @api
     * @deprecated Use ProductsBatch(SemknoxApi::putProductsBatch) instead.
     *
     * @return void
     */
    public function replaceAllProducts($productsArray)
    {
        $this->uploadProducts(json_encode($productsArray), true);
    }

    /**
     * Add a single product using JSON data
     *
     * @param string $jsonProductData JSON encoded product data, according to the API specification.
     *
     * @api
     *
     * @return void
     */
    public function addProductsByJson($jsonProductData)
    {
        $this->uploadProducts($jsonProductData, false);
    }

    /**
     * Replace all products by the provided products using JSON data
     *
     * @param string $jsonProductData JSON encoded product data, according to the API specification.
     *
     * @api
     * @deprecated Use ProductsBatch(SemknoxApi::putProductsBatch) instead.
     *
     * @return void
     */
    public function replaceAllProductsByJson($jsonProductData)
    {
        $this->uploadProducts($jsonProductData, true);
    }

    /**
     * Upload the data via PUT request
     *
     * @param string $jsonProductData
     * @param boolean $fullExport
     *
     * @return void
     */
    protected function uploadProducts($jsonProductData, $fullExport)
    {
        $this->api->requestPut(
            'products',
            [
                'full'              => $fullExport ? 'true' : 'false',
                'productsJsonArray' => urlencode($jsonProductData)
            ]
        );
    }
}
