<?php
/**
 * SEMKNOX API - PHP Library
 *
 * @copyright   Copyright (c) 2018 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Library\Semknox\Query;

use Semknox\Semknox\Library\Semknox\ApiCommunicator;

/**
 * Class UpdateCcss
 *
 * Updates custom search suggestions
 *
 * @package Semknox\Semknox\Library\Query
 */
class UpdateCcss
{

    const CCSS_TYPE_CATEGORY = "CATEGORY";
    const CCSS_TYPE_BRAND = "BRAND";
    const CCSS_TYPE_PRODUCT = "PRODUCT";

    /**
     * @var ApiCommunicator
     */
    protected $api;

    /**
     * UpdateCcss constructor.
     *
     * @param ApiCommunicator $apiCommunicator
     */
    public function __construct(
        ApiCommunicator $apiCommunicator
    ) {
        $this->api = $apiCommunicator;
    }

    /**
     * Update the Csss Data. See API manual.
     *
     * @param array $ccssData
     */
    public function viaArray($ccssData)
    {
        $this->sendRequest(json_encode($ccssData));
    }

    /**
     * Update the Csss Data using an already formatted json string. See API manual.
     *
     * @param string $jsonCcssData
     */
    public function viaJson($jsonCcssData)
    {
        $this->sendRequest($jsonCcssData);
    }

    /**
     * Upload the data via POST request
     *
     * @param $jsonCcssData
     *
     * @return void
     */
    protected function sendRequest($jsonCcssData)
    {
        $this->api->requestPost(
            'queries/updateCcss',
            ['ccssJson' => urlencode($jsonCcssData)]
        );
    }
}
