<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Artsiom Bruneuski <artsiom.bruneuski@tudock.de>
 */

namespace Semknox\Semknox\Model\Data\Result;

use Magento\Framework\DataObject;
use Magento\Framework\Api\DataObjectHelper;
use Semknox\Semknox\Library\Semknox\Api\Data\Result\FilterInterface;
use Semknox\Semknox\Library\Semknox\Api\Data\Result\Filter\OptionInterfaceFactory;

class Filter extends DataObject implements FilterInterface
{

    /**
     * @var OptionInterfaceFactory
     */
    protected $optionFactory;

    /**
     * @var DataObjectHelper
     */
    protected $dataObjectHelper;

    /**
     * Filter constructor.
     *
     * @param OptionInterfaceFactory $optionFactory
     * @param DataObjectHelper       $dataObjectHelper
     * @param array                  $data
     */
    public function __construct(
        OptionInterfaceFactory $optionFactory,
        DataObjectHelper $dataObjectHelper,
        array $data = []
    ) {
        $this->optionFactory = $optionFactory;
        $this->dataObjectHelper = $dataObjectHelper;
        parent::__construct($data);
    }

    /**
     * @return int
     */
    public function getId()
    {
        return $this->_getData(self::VAR_ID);
    }

    /**
     * @return string
     */
    public function getViewName()
    {
        return $this->_getData(self::VAR_VIEW_NAME);
    }

    /**
     * @return int
     */
    public function getCustomerId()
    {
        return $this->_getData(self::VAR_CUSTOMER_ID);
    }

    /**
     * @return int
     */
    public function getPosition()
    {
        return $this->_getData(self::VAR_POSITION);
    }

    /**
     * @return string
     */
    public function getUnitName()
    {
        return $this->_getData(self::VAR_UNIT_NAME);
    }

    /**
     * @return string
     */
    public function getType()
    {
        return $this->_getData(self::VAR_TYPE);
    }

    /**
     * @return string
     */
    public function getSortType()
    {
        return $this->_getData(self::VAR_SORT_TYPE);
    }

    /**
     * @return string
     */
    public function getLogic()
    {
        return $this->_getData(self::VAR_LOGIC);
    }

    /**
     * @return int
     */
    public function getTemplateFilterId()
    {
        return $this->_getData(self::VAR_TEMPLATE_FILTER_ID);
    }

    /**
     * @return int
     */
    public function getFillingDegree()
    {
        return $this->_getData(self::VAR_FILLING_DEGREE);
    }

    /**
     * @return int
     */
    public function getOptionCount()
    {
        return $this->_getData(self::VAR_OPTION_COUNT);
    }

    /**
     * @return bool
     */
    public function getActivateNewOptions()
    {
        return $this->_getData(self::VAR_ACTIVATE_NEW_OPTIONS);
    }

    /**
     * @return string[]
     */
    public function getOptions()
    {
        return $this->_getData(self::VAR_OPTIONS);
    }

    /**
     * @return array
     */
    public function getOptionsObjects()
    {
        $options = [];

        foreach ($this->getOptions() as $dataOption) {
            $option = $this->optionFactory->create();

            $this->dataObjectHelper->populateWithArray(
                $option,
                $dataOption,
                'Semknox\Semknox\Library\Semknox\Api\Data\Result\Filter\OptionInterface'
            );
            $options[] = $option;
        }

        return $options;
    }

    /**
     * @return int
     */
    public function getMin()
    {
        return $this->_getData(self::VAR_MIN);
    }

    /**
     * @return int
     */
    public function getMax()
    {
        return $this->_getData(self::VAR_MAX);
    }

    /**
     * @return int
     */
    public function getStep()
    {
        return $this->_getData(self::VAR_STEP);
    }

    /**
     * @return string
     */
    public function getIdName()
    {
        return $this->_getData(self::VAR_ID_NAME);
    }

    /**
     * @param int $id
     *
     * @return $this
     */
    public function setId($id)
    {
        $this->setData(self::VAR_ID, $id);
        return $this;
    }

    /**
     * @param string $viewName
     *
     * @return $this
     */
    public function setViewName($viewName)
    {
        $this->setData(self::VAR_VIEW_NAME, $viewName);
        return $this;
    }

    /**
     * @param int $customerId
     *
     * @return $this
     */
    public function setCustomerId($customerId)
    {
        $this->setData(self::VAR_CUSTOMER_ID, $customerId);
        return $this;
    }

    /**
     * @param int $position
     *
     * @return $this
     */
    public function setPosition($position)
    {
        $this->setData(self::VAR_POSITION, $position);
        return $this;
    }

    /**
     * @param string $unitName
     *
     * @return $this
     */
    public function setUnitName($unitName)
    {
        $this->setData(self::VAR_UNIT_NAME, $unitName);
        return $this;
    }

    /**
     * @param string $type
     *
     * @return $this
     */
    public function setType($type)
    {
        $this->setData(self::VAR_TYPE, $type);
        return $this;
    }

    /**
     * @param string $sortType
     *
     * @return $this
     */
    public function setSortType($sortType)
    {
        $this->setData(self::VAR_SORT_TYPE, $sortType);
        return $this;
    }

    /**
     * @param string $logic
     *
     * @return $this
     */
    public function setLogic($logic)
    {
        $this->setData(self::VAR_LOGIC, $logic);
        return $this;
    }

    /**
     * @param int $templateFilterId
     *
     * @return $this
     */
    public function setTemplateFilterId($templateFilterId)
    {
        $this->setData(self::VAR_TEMPLATE_FILTER_ID, $templateFilterId);
        return $this;
    }

    /**
     * @param int $fillingDegree
     *
     * @return $this
     */
    public function setFillingDegree($fillingDegree)
    {
        $this->setData(self::VAR_FILLING_DEGREE, $fillingDegree);
        return $this;
    }

    /**
     * @param int $optionCount
     *
     * @return $this
     */
    public function setOptionCount($optionCount)
    {
        $this->setData(self::VAR_OPTION_COUNT, $optionCount);
        return $this;
    }

    /**
     * @param bool $activateNewOptions
     *
     * @return $this
     */
    public function setActivateNewOptions($activateNewOptions)
    {
        $this->setData(self::VAR_ACTIVATE_NEW_OPTIONS, $activateNewOptions);
        return $this;
    }

    /**
     * @param \string[] $options
     *
     * @return $this
     */
    public function setOptions($options)
    {
        $this->setData(self::VAR_OPTIONS, $options);
        return $this;
    }

    /**
     * @param int $min
     *
     * @return $this
     */
    public function setMin($min)
    {
        $this->setData(self::VAR_MIN, $min);
        return $this;
    }

    /**
     * @param int $max
     *
     * @return $this
     */
    public function setMax($max)
    {
        $this->setData(self::VAR_MAX, $max);
        return $this;
    }

    /**
     * @param int $step
     *
     * @return $this
     */
    public function setStep($step)
    {
        $this->setData(self::VAR_STEP, $step);
        return $this;
    }

    /**
     * @param string $idName
     *
     * @return $this
     */
    public function setIdName($idName)
    {
        $this->setData(self::VAR_ID_NAME, $idName);
        return $this;
    }
}
