<?php

/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Artsiom Bruneuski <artsiom.bruneuski@tudock.de>
 */

namespace Semknox\Semknox\Model\Layer;

use Magento\Catalog\Model\Layer\FilterableAttributeListInterface;
use Magento\Framework\App\Request\Http as HttpRequest;
use Semknox\Semknox\Helper\ApiConnection;
use Semknox\Semknox\Library\SearchResult\LibFilterInterface;

class FilterList extends \Magento\Catalog\Model\Layer\FilterList
{
    const SEARCH_FILTER_ATTRIBUTE = 'semknox_attribute';
    const SEARCH_FILTER_MULTI_SELECT = 'semknox_multi_select';
    const SEARCH_FILTER_RANGE = 'semknox_range';

    /**
     * @var ApiConnection
     */
    protected $apiConnection;

    /**
     * FilterList constructor.
     * @param \Magento\Framework\ObjectManagerInterface $objectManager
     * @param FilterableAttributeListInterface $filterableAttributes
     * @param ApiConnection $apiConnection
     * @param array $filters
     */
    public function __construct(
        \Magento\Framework\ObjectManagerInterface $objectManager,
        FilterableAttributeListInterface $filterableAttributes,
        ApiConnection $apiConnection,
        array $filters = []
    ) {
        $this->apiConnection = $apiConnection;

        return parent::__construct($objectManager, $filterableAttributes, $filters);
    }

    /**
     * Retrieve list of filters
     *
     * @param \Magento\Catalog\Model\Layer $layer
     * @return array|Filter\AbstractFilter[]
     */
    public function getFilters(\Magento\Catalog\Model\Layer $layer)
    {
        if (!count($this->filters) && $search = $this->apiConnection->getSearch()) {
            $filters = $search->getFilters();

            foreach ($filters as $filter) {
                if ($filter->getType() === LibFilterInterface::FILTER_TYPE_RANGE) {
                    $this->filters[] = $this->objectManager->create(
                        $this->filterTypes[self::SEARCH_FILTER_RANGE],
                        [
                            'filter' => $filter,
                            'layer' => $layer
                        ]
                    );
                } elseif ($filter->getType() === LibFilterInterface::FILTER_TYPE_MULTI_SELECT) {
                    $this->filters[] = $this->objectManager->create(
                        $this->filterTypes[self::SEARCH_FILTER_MULTI_SELECT],
                        [
                            'filter' => $filter,
                            'layer' => $layer
                        ]
                    );
                } else {
                    $this->filters[] = $this->objectManager->create($this->filterTypes[
                        self::SEARCH_FILTER_ATTRIBUTE], [
                            'filter' => $filter,
                            'layer' => $layer
                        ]);
                }
            }
        }
        return $this->filters;
    }
}
