<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Artsiom Bruneuski <artsiom.bruneuski@tudock.de>
 */
namespace Semknox\Semknox\Observer\CatalogSearch\Result;

use Magento\Framework\Event\ObserverInterface;

class Index implements ObserverInterface
{
    /** @var \Magento\Framework\App\Action\Context  */
    protected $context;

    /** @var \Magento\Framework\Translate\InlineInterface  */
    protected $translateInline;

    /**
     * Index constructor.
     * @param \Magento\Framework\App\Action\Context $context
     * @param \Magento\Framework\Translate\InlineInterface $translateInline
     */
    public function __construct(
        \Magento\Framework\App\Action\Context $context,
        \Magento\Framework\Translate\InlineInterface $translateInline
    ) {

        $this->context = $context;
        $this->translateInline = $translateInline;
    }

    /**
     * @return bool
     */
    public function isPjaxHttpRequest()
    {
        $request = $this->context->getRequest();
        $header = $request->getHeaders()->get('X-PJAX');
        return false !== $header && $header->getFieldValue() == 'true';
    }

    /**
     * Output only data from body for PJAX request
     * @param \Magento\Framework\Event\Observer $observer
     * @return null
     */
    public function execute(\Magento\Framework\Event\Observer $observer)
    {
        if ($this->isPjaxHttpRequest()) {
            $output = $this->context->getView()->getLayout()->getOutput();
            $this->translateInline->processResponseBody($output);
            $this->context->getResponse()->setBody($output);
        }
    }
}
