<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */

namespace Semknox\Semknox\Plugin\Indexer;

use Magento\Catalog\Model\ResourceModel\Attribute as OriginalAttribute;
use Magento\Framework\Model\AbstractModel;
use Magento\Framework\Search\Request\Config;
use Semknox\Semknox\Service\IndexerService;

class Attribute
{

    /** @var IndexerService */
    protected $indexerService;

    /**
     * @var Config
     */
    private $config;

    /**
     * @param IndexerService $indexerService
     * @param Config         $config
     */
    public function __construct(
        IndexerService $indexerService,
        Config $config
    ) {
        $this->config         = $config;
        $this->indexerService = $indexerService;
    }

    /**
     * Invalidate indexer when searchable attribute change
     *
     * @param OriginalAttribute $subject
     * @param \Closure          $proceed
     * @param AbstractModel     $attribute
     *
     * @return OriginalAttribute
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function aroundSave(
        OriginalAttribute $subject,
        \Closure $proceed,
        AbstractModel $attribute
    ) {
        $isNew            = $attribute->isObjectNew();
        $needInvalidation = $this->attributeChanged($attribute) && !$isNew;

        $result = $proceed($attribute);
        if ($needInvalidation) {
            $this->indexerService->invalidate();
        }
        if ($isNew || $needInvalidation) {
            $this->config->reset();
        }

        return $result;
    }

    /**
     * Invalidate indexer on searchable attribute delete
     *
     * @param OriginalAttribute $subject
     * @param \Closure          $proceed
     * @param AbstractModel     $attribute
     *
     * @return OriginalAttribute
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function aroundDelete(
        OriginalAttribute $subject,
        \Closure $proceed,
        AbstractModel $attribute
    ) {
        $needInvalidation = !$attribute->isObjectNew() && $this->attributeChanged($attribute);
        $result           = $proceed($attribute);
        if ($needInvalidation) {
            $this->indexerService->invalidate();
        }

        return $result;
    }

    /**
     * @param AbstractModel $attribute
     *
     * @return bool
     */
    private function attributeChanged($attribute)
    {
        return $attribute->dataHasChangedFor('is_searchable')
        || $attribute->dataHasChangedFor('is_filterable')
        || $attribute->dataHasChangedFor('is_visible_in_advanced_search');
    }
}
