<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */

namespace Semknox\Semknox\Plugin\Indexer;

use Magento\Catalog\Model\ResourceModel\Product as OriginalResource;
use Magento\Framework\Model\AbstractModel;
use Semknox\Semknox\Service\IndexerResourceAttachment;

class Product
{

    /** @var  IndexerResourceAttachment */
    protected $indexerResourceAttachment;

    /**
     * @param IndexerResourceAttachment $indexerResourceAttachment
     */
    public function __construct(
        IndexerResourceAttachment $indexerResourceAttachment
    ) {
        $this->indexerResourceAttachment = $indexerResourceAttachment;
    }

    /**
     * Reindex when product is saved
     *
     * @param OriginalResource $resource
     * @param \Closure         $proceed
     * @param AbstractModel    $model
     *
     * @return OriginalResource
     */
    public function aroundSave(OriginalResource $resource, \Closure $proceed, AbstractModel $model)
    {
        return $this->indexerResourceAttachment->execute($resource, $proceed, $model, $model->getEntityId());
    }

    /**
     * Reindex when product is deleted
     *
     * @param OriginalResource $resource
     * @param \Closure         $proceed
     * @param AbstractModel    $model
     *
     * @return OriginalResource
     */
    public function aroundDelete(OriginalResource $resource, \Closure $proceed, AbstractModel $model)
    {
        return $this->indexerResourceAttachment->execute($resource, $proceed, $model, $model->getEntityId());
    }
}
