<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */

namespace Semknox\Semknox\Plugin\Indexer\Product;

use Magento\Catalog\Model\Product\Action as OriginalAction;
use Semknox\Semknox\Service\IndexerService;

class Action
{

    /** @var IndexerService */
    protected $indexerService;

    /**
     * @param IndexerService $indexerService
     */
    public function __construct(
        IndexerService $indexerService
    ) {
        $this->indexerService = $indexerService;
    }

    /**
     * Reindex on product attribute changes, likely caused by mass action
     *
     * @param OriginalAction $subject
     * @param \Closure       $closure
     * @param array          $productIds
     * @param array          $attrData
     * @param int            $storeId
     *
     * @return $this
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function aroundUpdateAttributes(
        OriginalAction $subject,
        \Closure $closure,
        array $productIds,
        array $attrData,
        $storeId
    ) {
        $result = $closure($productIds, $attrData, $storeId);
        $this->indexerService->execute(array_unique($productIds));

        return $result;
    }

    /**
     * Reindex on product change if website changes
     *
     * @param OriginalAction $subject
     * @param \Closure       $closure
     * @param array          $productIds
     * @param array          $websiteIds
     * @param string         $type
     *
     * @return $this
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function aroundUpdateWebsites(
        OriginalAction $subject,
        \Closure $closure,
        array $productIds,
        array $websiteIds,
        $type
    ) {
        $result = $closure($productIds, $websiteIds, $type);
        $this->indexerService->execute(array_unique($productIds));

        return $result;
    }
}
