<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Plugin\Model\Layer\Filter;

use Magento\Framework\App\Helper\Context;
use Magento\Store\Model\StoreManagerInterface;
use Semknox\Semknox\Helper\Compatibility;
use Semknox\Semknox\Library\Exception\ApiException;
use Semknox\Semknox\Library\Exception\ApiNotAuthenticatedException;
use Semknox\Semknox\Library\LibEntrypointInterface;
use Semknox\Semknox\Library\LibEntrypointInterfaceFactory;
use Magento\Framework\Stdlib\StringUtils;

use Magento\Framework\App\Request\Http as HttpRequest;
use Semknox\Semknox\Library\SearchResult\LibSearchResultInterface;

/**
 * Compatibility class for modules affecting the layered navigation
 *
 * Class Item
 * @package Mageplaza\LayeredNavigation\Model\Plugin\Layer\Filter
 */
class Item
{

    /**
     * @var Compatibility
     */
    protected $compatibility;

    /** @var \Magento\Framework\UrlInterface */
    protected $url;

    /** @var \Magento\Theme\Block\Html\Pager */
    protected $htmlPagerBlock;

    /**
     * Item constructor.
     *
     * @param Compatibility $compatibility
     */
    public function __construct(
        Compatibility $compatibility,
        \Magento\Framework\UrlInterface $url,
        \Magento\Theme\Block\Html\Pager $htmlPagerBlock
    ) {
        $this->compatibility = $compatibility;
        $this->url            = $url;
        $this->htmlPagerBlock = $htmlPagerBlock;
    }

    /**
     * Prevent overriding the getUrl method by Mageplaza_LayeredNavigation when in search
     *
     * @param \Magento\Catalog\Model\Layer\Filter\Item $subject
     * @param callable                                 $proceed
     *
     * @return string
     *
     */
    public function aroundGetUrl(\Magento\Catalog\Model\Layer\Filter\Item $subject, callable $proceed)
    {
        if ($this->compatibility->isMageplazaLayeredNavigationActivated() && $subject->getFilter() instanceof \Semknox\Semknox\Model\Layer\Filter\Attribute) {
            // Return the original URL
            // Sadly the LayeredNavigation interrupts the plugin chain, so we have to as well....

            // This code is the original Filter item getUrl() code.
            // Because LN interrupts the chain we have no way of accesing it, I had to copy the code
            $query = [
                $subject->getFilter()->getRequestVar() => $subject->getValue(),
                // exclude current page from urls
                $this->htmlPagerBlock->getPageVarName() => null,
            ];
            return $this->url->getUrl('*/*/*', ['_current' => true, '_use_rewrite' => true, '_query' => $query]);
        } else {
            return $proceed();
        }
    }
}
