<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */

namespace Semknox\Semknox\Service;

use Magento\Framework\Model\AbstractModel;
use Magento\Framework\Model\ResourceModel\AbstractResource;

/**
 * Attach the reindexing of a product to a specific resource model related transaction
 *
 * @package Semknox\Semknox\Service
 */
class IndexerResourceAttachment
{

    /** @var IndexerService */
    protected $indexerService;

    /**
     * @param IndexerService $indexerService
     */
    public function __construct(
        IndexerService $indexerService
    ) {
        $this->indexerService = $indexerService;
    }

    /**
     * @param AbstractResource $resource
     * @param \Closure         $preCallback
     * @param AbstractModel    $model
     * @param int              $productId
     *
     * @return mixed
     * @throws \Exception
     */
    public function execute(AbstractResource $resource, \Closure $preCallback, AbstractModel $model, $productId)
    {
        try {
            $resource->beginTransaction();
            $preCallbackResult = $preCallback($model);
            $resource->addCommitCallback(
                function () use ($productId) {
                    $this->indexerService->execute($productId);
                }
            );
            $resource->commit();
        } catch (\Exception $e) {
            $resource->rollBack();
            throw $e;
        }

        return $preCallbackResult;
    }
}
