<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */

namespace Semknox\Semknox\Service;

use Semknox\Semknox\Model\Indexer;

class IndexerService
{

    /** @var \Magento\Framework\Indexer\IndexerRegistry */
    protected $indexerRegistry;

    /**
     * @param \Magento\Framework\Indexer\IndexerRegistry $indexerRegistry
     */
    public function __construct(
        \Magento\Framework\Indexer\IndexerRegistry $indexerRegistry
    ) {
        $this->indexerRegistry = $indexerRegistry;
    }

    /**
     * Reindex product if index is not set to be scheduled
     *
     * @param int|int[] $productIds
     *
     * @return void
     */
    public function execute($productIds)
    {
        $indexer = $this->indexerRegistry->get(Indexer\Product::INDEXER_ID);
        if (!$indexer->isScheduled()) {
            if (is_array($productIds)) {
                $indexer->reindexList($productIds);
            } else {
                $indexer->reindexRow($productIds);
            }
        }
    }

    /**
     * Invalidate index
     *
     * @return void
     */
    public function invalidate()
    {
        $this->indexerRegistry->get(Indexer\Product::INDEXER_ID)->invalidate();
    }
}
