<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Service\InitialUpload;

use Semknox\Semknox\Helper\InitialUpload\InfoHelperInterface;
use Semknox\Semknox\Service\InitialUpload\Task\ProductCollectingFactory;
use Semknox\Semknox\Service\InitialUpload\Task\ProductUploadingFactory;

class Schedule implements ScheduleInterface
{

    /**
     * @var ProductCollectingFactory
     */
    protected $productCollectingFactory;

    /**
     * @var ProductUploadingFactory
     */
    protected $productUploadingFactory;

    /**
     * Schedule constructor.
     *
     * @param ProductCollectingFactory $productCollectingFactory
     * @param ProductUploadingFactory  $productUploadingFactory
     */
    public function __construct(
        ProductCollectingFactory $productCollectingFactory,
        ProductUploadingFactory $productUploadingFactory
    ) {
        $this->productCollectingFactory = $productCollectingFactory;
        $this->productUploadingFactory  = $productUploadingFactory;
    }

    /**
     * An array of tasks, in the format:
     *  [weight => <weight in progress bar, sum has to be 100>,
     *   key => <runner state key>,
     *   factory => <Task Factory Class>]
     * WAITING is always the first task and it will then transition to the first task in this list.
     *
     * @return array
     */
    public function getSchedule()
    {
        return [
            [
                "key" => InfoHelperInterface::RUNNER_COLLECTING,
                "weight" => 90,
                "factory" => $this->productCollectingFactory
            ],
            [
                "key" => InfoHelperInterface::RUNNER_READY_FOR_UPLOAD,
                "weight" => 10,
                "factory" => $this->productUploadingFactory
            ]
        ];
    }
}
