<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */

namespace Semknox\Semknox\Service;

use Magento\Catalog\Model\Product;
use Magento\Catalog\Model\Product\Attribute\Source\Status;
use Magento\Catalog\Model\ProductFactory;
use Magento\Catalog\Model\ResourceModel\Category\CollectionFactory;
use Magento\CatalogInventory\Helper\Stock;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Store\Api\Data\StoreInterface;
use Magento\Store\Model\ScopeInterface;

class UploadCollectionCreator
{

    /**
     * @var ProductFactory
     */
    protected $productFactory;

    /**
     * @var \Magento\Catalog\Model\Product\Visibility
     */
    protected $productVisibility;

    /**
     * @var Status
     */
    protected $productStatus;

    /**
     * @var ScopeConfigInterface
     */
    protected $config;

    /**
     * @var Stock
     */
    protected $stockFilter;

    /**
     * UploadCollectionCreator constructor.
     *
     * @param CollectionFactory    $productCollectionFactory
     * @param ScopeConfigInterface $config
     * @param Product\Visibility   $productVisibility
     * @param Status               $productStatus
     * @param Stock                $stockFilter
     */
    public function __construct(
        ProductFactory $productFactory,
        ScopeConfigInterface $config,
        Product\Visibility $productVisibility,
        Status $productStatus,
        Stock $stockFilter
    ) {
        $this->productFactory = $productFactory;
        $this->config = $config;
        $this->productVisibility = $productVisibility;
        $this->productStatus = $productStatus;
        $this->stockFilter = $stockFilter;
    }

    /**
     * Creates a product collection with filters set the match the current search settings.
     *
     * @param StoreInterface $store
     *
     * @param bool           $addFilters    Add additional filters for collection
     *
     * @return \Magento\Catalog\Model\ResourceModel\Product\Collection
     */
    public function execute($store, $addFilters = true)
    {
        /** @var \Magento\Catalog\Model\ResourceModel\Product\Collection $collection */
        $collection = $this->productFactory->create()->getCollection()
                ->setStore($store)
                ->addAttributeToSelect('visibility'); // Select no attributes, because the product has to be reloaded anyway
        if ($addFilters) {
            $collection
                ->addAttributeToFilter('status', ['in' => $this->getVisibleStatusIds()])
                ->setVisibility($this->getVisibleInSearchIds());

            // Removes out of stock products from the collection if set in backend

            if ($this->showOutOfStock() === false) {
                $this->stockFilter->addInStockFilterToCollection($collection);
            }
        }
        return $collection;
    }

    public function showOutOfStock()
    {
        return $this->config->isSetFlag(
            'cataloginventory/options/show_out_of_stock',
            ScopeInterface::SCOPE_STORE
        );
    }

    public function getVisibleStatusIds()
    {
        return $this->productStatus->getVisibleStatusIds();
    }

    public function getVisibleInSearchIds()
    {
        return $this->productVisibility->getVisibleInSearchIds();
    }
}
