<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Artsiom Bruneuski <artsiom.bruneuski@tudock.de>
 */
namespace Semknox\Semknox\Setup;

use Magento\Framework\Setup\InstallDataInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\ModuleDataSetupInterface;
use Magento\Framework\Indexer\IndexerInterfaceFactory;

use Magento\Cms\Model\BlockFactory;
use Magento\Cms\Model\BlockRepository;
use Magento\Cms\Model\Block as CmsBlock;

class InstallData implements InstallDataInterface
{

    /** @var BlockFactory  */
    protected $blockFactory;

    /** @var BlockRepository  */
    protected $blockRepository;

    public function __construct(
        BlockFactory $blockFactory,
        BlockRepository $blockRepository
    ) {
        $this->blockFactory = $blockFactory;
        $this->blockRepository = $blockRepository;
    }

    /**
     * Installs data for a module
     *
     * @param ModuleDataSetupInterface $setup
     * @param ModuleContextInterface $context
     * @return void
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function install(ModuleDataSetupInterface $setup, ModuleContextInterface $context)
    {
        // Double tudock for historic reasons
        $blockId = 'tudock_semknox_search_tips';

        /** @var CmsBlock $block */
        $block = $this->blockFactory->create();
        $block->getResource()->load($block, $blockId, 'identifier');
        if ($block->getId()) {
            //Delete old version block
            $this->blockRepository->delete($block);
        }

        $content = <<<EOT
<h2>Tipps zu Ihrer Suche:</h2>
<ul>
<li>Bitte kontrollieren Sie noch einmal die Schreibweise Ihrer Suchanfrage auf eventuelle Tippfehler</li>
<li>Suchen Sie nach einem ähnlichen Begriff bzw. einem Synonym.</li>
<li>Versuchen Sie, allgemein zu suchen. Sie können die Suchergebnisse anschließend noch eingrenzen.</li></ul>
EOT;

        $this->createBlock($blockId, $content);
    }

    /**
     * @param mixed $blockId
     * @param mixed $content
     * @return null
     */
    protected function createBlock($blockId, $content)
    {
        /** @var CmsBlock $block */
        $block = $this->blockFactory->create();

        $block->setIdentifier($blockId)
            ->setTitle($blockId)
            ->setContent($content);

        $this->blockRepository->save($block);
    }
}
