<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Test\Unit\Block\Adminhtml\System\Config\Fieldset;

use Semknox\Semknox\Library\Exception\ApiException;
use Semknox\Semknox\Library\Exception\ApiNotAuthenticatedException;
use Semknox\Semknox\Helper\ApiConnection;

class StatusTest extends \PHPUnit\Framework\TestCase
{

    /**
     * @var \Semknox\Semknox\Block\Adminhtml\System\Config\Fieldset\Status
     */
    protected $statusBlock;

    /**
     * @var ApiConnection|\PHPUnit_Framework_MockObject_MockObject
     */
    protected $apiConnectionMock;

    protected $storeId;

    public function setUp()
    {
        $this->storeId = 100;

        $objectManager = new \Magento\Framework\TestFramework\Unit\Helper\ObjectManager($this);

        $this->apiConnectionMock = $this->getMockBuilder('\Semknox\Semknox\Helper\ApiConnection')
            ->disableOriginalConstructor()
            ->getMock();

        $this->statusBlock = $objectManager->getObject(
            'Semknox\Semknox\Block\Adminhtml\System\Config\Fieldset\Status',
            [
                'apiConnection' => $this->apiConnectionMock
            ]
        );
    }

    /**
     * @covers \Semknox\Semknox\Block\Adminhtml\System\Config\Fieldset\Status::apiIsAuthenticated
     */
    public function testApiIsAuthenticatedPositive()
    {

        $this->apiConnectionMock->expects(self::any())
            ->method('isAuthenticated')
            ->with($this->storeId)
            ->willReturn(true);

        $reflection = new \ReflectionClass(get_class($this->statusBlock));
        $method     = $reflection->getMethod('apiIsAuthenticated');
        $method->setAccessible(true);

        $this->assertTrue(
            $method->invokeArgs($this->statusBlock, [$this->storeId]),
            "The internal check for API accessibility needs to report true, if a result is returned."
        );
    }

    /**
     * @covers \Semknox\Semknox\Block\Adminhtml\System\Config\Fieldset\Status::apiIsAuthenticated
     */
    public function testApiIsAuthenticatedNegative()
    {

        $this->apiConnectionMock->expects(self::any())
            ->method('isAuthenticated')
            ->with($this->storeId)
            ->willReturn(false);

        $reflection = new \ReflectionClass(get_class($this->statusBlock));
        $method     = $reflection->getMethod('apiIsAuthenticated');
        $method->setAccessible(true);

        $this->assertFalse(
            $method->invokeArgs($this->statusBlock, [$this->storeId]),
            "The internal check for API accessibility needs to report false, 
            if a ApiNotAtuhenticatedException is thrown"
        );
    }

    /**
     * @covers \Semknox\Semknox\Block\Adminhtml\System\Config\Fieldset\Status::apiIsAuthenticated
     * @expectedException \Semknox\Semknox\Library\Exception\ApiException
     * The internal check for API accessibility needs to pass the ApiException on errors
     */
    public function testApiIsAuthenticatedError()
    {

        $this->apiConnectionMock->expects(self::any())
            ->method('isAuthenticated')
            ->with($this->storeId)
            ->willThrowException(new ApiException());

        $reflection = new \ReflectionClass(get_class($this->statusBlock));
        $method     = $reflection->getMethod('apiIsAuthenticated');
        $method->setAccessible(true);

        $method->invokeArgs($this->statusBlock, [$this->storeId]);
    }
}
