<?php
/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */

namespace Semknox\Semknox\Test\Unit\Helper\InitialUpload;

use Semknox\Semknox\Helper\InitialUpload\Logger;

class LoggerTest extends \PHPUnit\Framework\TestCase
{

    /**
     * @var Logger
     */
    protected $logger;

    /**
     * @var \PHPUnit_Framework_MockObject_MockObject|\Psr\Log\LoggerInterface
     */
    protected $psrLoggerMock;

    /**
     * @var string
     */
    protected $message;

    /**
     * @var string
     */
    protected $messageResult;

    /**
     * @var int
     */
    protected $storeId;

    /**
     * @var InfoHelperStub
     */
    protected $infoHelperStub;

    /**
     * @var array
     */
    protected $infoHelperStubData;

    public function setUp()
    {
        $objectManager = new \Magento\Framework\TestFramework\Unit\Helper\ObjectManager($this);

        $this->psrLoggerMock = $this->getMockBuilder('\Psr\Log\LoggerInterface')
            ->getMock();

        $this->storeId       = rand(0, 100);
        $this->message       = 'Test Message ' . md5(rand(0, 100));
        $this->messageResult = 'SKNOX Upload [PID ' . getmypid() .
            ' | Store ' . $this->storeId . ']: ' . $this->message;

        $this->infoHelperStubData = [
            'process'       => 'SEMKNOX Initial Upload',
            'state'         => md5(rand(0, 100)),
            'runnerState'   => md5(rand(0, 100)),
            'interruptable' => rand(0, 1) == 1,
            'batch'         => rand(0, 100),
            'progress'      => rand(0, 100),
            'storeId'       => $this->storeId
        ];

        $this->infoHelperStub = new InfoHelperStub();
        $this->infoHelperStub->setState($this->infoHelperStubData['state']);
        $this->infoHelperStub->setRunnerState($this->infoHelperStubData['runnerState']);
        $this->infoHelperStub->setInterruptable($this->infoHelperStubData['interruptable']);
        $this->infoHelperStub->setBatch($this->infoHelperStubData['batch']);
        $this->infoHelperStub->setProgress($this->infoHelperStubData['progress']);
        $this->infoHelperStub->setStoreId($this->infoHelperStubData['storeId']);

        $this->logger = $objectManager->getObject(
            'Semknox\Semknox\Helper\InitialUpload\Logger',
            [
                'logger' => $this->psrLoggerMock
            ]
        );
    }

    /**
     * @covers \Semknox\Semknox\Helper\InitialUpload\Logger::info
     * @covers \Semknox\Semknox\Helper\InitialUpload\Logger::log
     */
    public function testInfo()
    {
        $this->psrLoggerMock->expects(self::once())
            ->method('log')
            ->with(\Monolog\Logger::INFO, $this->messageResult, $this->infoHelperStubData);
        $this->logger->info($this->message, $this->infoHelperStub);
    }

    /**
     * @covers \Semknox\Semknox\Helper\InitialUpload\Logger::error
     * @covers \Semknox\Semknox\Helper\InitialUpload\Logger::log
     */
    public function testError()
    {
        $this->psrLoggerMock->expects(self::once())
            ->method('log')
            ->with(\Monolog\Logger::ERROR, $this->messageResult, $this->infoHelperStubData);
        $this->logger->error($this->message, $this->infoHelperStub);
    }

    /**
     * @covers \Semknox\Semknox\Helper\InitialUpload\Logger::debug
     * @covers \Semknox\Semknox\Helper\InitialUpload\Logger::log
     */
    public function testDebug()
    {
        if (!Logger::DEBUG_ENABLED) {
            $this->markTestSkipped('Debug logging is disabled, only the enabled case is tested.');
        }
        $this->psrLoggerMock->expects(self::once())
            ->method('log')
            ->with(\Monolog\Logger::DEBUG, $this->messageResult, $this->infoHelperStubData);
        $this->logger->debug($this->message, $this->infoHelperStub);
    }
}
