<?php
namespace Semknox\Semknox\Test\Unit\Library;

/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */

use Semknox\Semknox\Library\Exception\ApiException;
use Semknox\Semknox\Library\Exception\ApiNotAuthenticatedException;

/**
 * Class LibAuthenticationStub
 *
 * Simple implementation for testing
 */
class LibAuthenticationStub implements \Semknox\Semknox\Library\LibAuthenticationInterface
{

    protected $configuration = null;

    /**
     * @var mixed|ApiException
     */
    protected $testConnectionReturnValue = null;

    /**
     * Set the required authentication/connection configuration.
     * The input is an associative array.
     * The fields of the array depend on the actual library being used,
     * as a hint getConfigurationFields can be used to retrieve the fields that need to be set
     *
     * @param array $configData
     *
     * @return void
     */
    public function setConfiguration($configData)
    {
        $this->configuration = $configData;
    }

    /**
     * @return array
     */
    public function getConfiguration()
    {
        return $this->configuration;
    }

    /**
     * Returns an array of strings containing the field names required by setConfiguration.
     * This may or may not be used to automatically provide configuration fields in the backend.
     * It is not used by the main module Semknox_Semknox as of August 2017.
     *
     * @return string[]
     */
    public function getConfigurationFields()
    {
        return ["NOT IMPLEMENTED YET"];
    }

    /**
     * @return null
     * @throws \Exception
     */
    public function testConnection()
    {
        // XXX: Code Sniffer Bug. Throwing variables not possible.
        if ($this->testConnectionReturnValue instanceof ApiNotAuthenticatedException) {
            throw new ApiNotAuthenticatedException($this->testConnectionReturnValue->getMessage(), $this->testConnectionReturnValue->getResponseBody(), $this->testConnectionReturnValue->getCode());
        } elseif ($this->testConnectionReturnValue instanceof ApiException) {
            throw new ApiException($this->testConnectionReturnValue->getMessage(), $this->testConnectionReturnValue->getResponseBody(), $this->testConnectionReturnValue->getCode());
        } else {
            return $this->testConnectionReturnValue;
        }
    }

    public function testConnectionShouldReturn($testConnectionReturnValue)
    {
        $this->testConnectionReturnValue = $testConnectionReturnValue;
    }
}
