<?php
/**
 * SEMKNOX API - PHP Library
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Test\Unit\Library;

use Semknox\Semknox\Library\LibAuthentication;
use Semknox\Semknox\Library\Semknox\SemknoxApi;
use Semknox\Semknox\Library\Semknox\ApiConfig;

class LibAuthenticationTest extends \PHPUnit\Framework\TestCase
{

    /**
     * @var \PHPUnit_Framework_MockObject_MockObject|SemknoxApi
     */
    protected $semknoxApiMock;

    /**
     * @var LibAuthentication
     */
    protected $auth;

    /**
     * @var \PHPUnit_Framework_MockObject_MockObject|ApiConfig
     */
    protected $userCredentialsMock;

    /**
     * Setup classes
     * @return void
     */
    public function setUp()
    {
        $objectManager = new \Magento\Framework\TestFramework\Unit\Helper\ObjectManager($this);

        $this->userCredentialsMock = $this
            ->getMockBuilder('\Semknox\Semknox\Library\Semknox\ApiConfig')
            ->disableOriginalConstructor()->getMock();

        $this->semknoxApiMock = $this->getMockBuilder('\Semknox\Semknox\Library\Semknox\SemknoxApi')
            ->disableOriginalConstructor()->getMock();

        $this->semknoxApiMock->expects(self::any())
            ->method('getApiConfig')
            ->willReturn($this->userCredentialsMock);

        $this->auth = $objectManager->getObject(
            '\Semknox\Semknox\Library\LibAuthentication',
            [
                'semknoxApi'                => $this->semknoxApiMock
            ]
        );
    }

    /**
     * @return void
     */
    public function testSetConfiguration()
    {
        $valueA = (string)random_int(1, 200);
        $valueB = (string)random_int(1, 200);
        $valueC = (string)random_int(1, 200);

        $this->userCredentialsMock->expects(self::once())
            ->method('setCustomerId')
            ->with($valueA);

        $this->userCredentialsMock->expects(self::once())
            ->method('setApiKey')
            ->with($valueB);

        $this->userCredentialsMock->expects(self::once())
            ->method('setApiUrl')
            ->with($valueC);

        $this->auth->setConfiguration([
            'customer_id' => $valueA,
            'api_key' => $valueB,
            'api_url' => $valueC
        ]);
    }
}
