<?php
/**
 * SEMKNOX API - PHP Library
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Test\Unit\Library;

use Semknox\Semknox\Library\LibAuthentication;
use Semknox\Semknox\Library\LibEntrypoint;
use Semknox\Semknox\Library\LibFeatures;
use Semknox\Semknox\Library\LibSearch;
use Semknox\Semknox\Library\LibUpdate;
use Semknox\Semknox\Library\Semknox\SemknoxApi;

class LibEntrypointTest extends \PHPUnit\Framework\TestCase
{

    /**
     * @var \PHPUnit_Framework_MockObject_MockObject|SemknoxApi
     */
    protected $semknoxApiMock;

    /**
     * @var \PHPUnit_Framework_MockObject_MockObject|LibAuthentication
     */
    protected $authMock;

    /**
     * @var \PHPUnit_Framework_MockObject_MockObject|LibFeatures
     */
    protected $featureMock;

    /**
     * @var \PHPUnit_Framework_MockObject_MockObject|LibSearch
     */
    protected $searchMock;

    /**
     * @var \PHPUnit_Framework_MockObject_MockObject|LibUpdate
     */
    protected $updateMock;

    /**
     * @var LibEntrypoint
     */
    protected $entrypoint;

    /**
     * Setup classes
     * @return void
     */
    public function setUp()
    {
        $objectManager = new \Magento\Framework\TestFramework\Unit\Helper\ObjectManager($this);

        $this->semknoxApiMock = $this->getMockBuilder('\Semknox\Semknox\Library\Semknox\SemknoxApi')
            ->disableOriginalConstructor()->getMock();
        $semknoxApiFactoryMock = $this
            ->getMockBuilder('\Semknox\Semknox\Library\Semknox\SemknoxApiFactory')
            ->disableOriginalConstructor()
            ->setMethods(['create'])
            ->getMock();
        $semknoxApiFactoryMock->expects(self::any())
            ->method('create')
            ->willReturn($this->semknoxApiMock);

        $this->authMock = $this->getMockBuilder('\Semknox\Semknox\Library\LibAuthentication')
            ->disableOriginalConstructor()->getMock();
        $authFactoryMock = $this->getMockBuilder('\Semknox\Semknox\Library\LibAuthenticationFactory')
            ->disableOriginalConstructor()
            ->setMethods(['create'])
            ->getMock();
        $authFactoryMock->expects(self::any())
            ->method('create')
            ->with(['semknoxApi' => $this->semknoxApiMock])
            ->willReturn($this->authMock);

        $this->featureMock = $this->getMockBuilder('\Semknox\Semknox\Library\LibFeatures')
            ->disableOriginalConstructor()->getMock();
        $featuresFactoryMock = $this->getMockBuilder('\Semknox\Semknox\Library\LibFeaturesFactory')
            ->disableOriginalConstructor()
            ->setMethods(['create'])
            ->getMock();
        $featuresFactoryMock->expects(self::any())
            ->method('create')
            ->with(['semknoxApi' => $this->semknoxApiMock])
            ->willReturn($this->featureMock);

        $this->searchMock = $this->getMockBuilder('\Semknox\Semknox\Library\LibSearch')
            ->disableOriginalConstructor()->getMock();
        $searchFactoryMock = $this->getMockBuilder('\Semknox\Semknox\Library\LibSearchFactory')
            ->disableOriginalConstructor()
            ->setMethods(['create'])
            ->getMock();
        $searchFactoryMock->expects(self::any())
            ->method('create')
            ->with(['semknoxApi' => $this->semknoxApiMock])
            ->willReturn($this->searchMock);

        $this->updateMock = $this->getMockBuilder('\Semknox\Semknox\Library\LibUpdate')
            ->disableOriginalConstructor()->getMock();
        $updateFactoryMock = $this->getMockBuilder('\Semknox\Semknox\Library\LibUpdateFactory')
            ->disableOriginalConstructor()
            ->setMethods(['create'])
            ->getMock();
        $updateFactoryMock->expects(self::any())
            ->method('create')
            ->with(['semknoxApi' => $this->semknoxApiMock])
            ->willReturn($this->updateMock);

        $this->entrypoint = $objectManager->getObject(
            '\Semknox\Semknox\Library\LibEntrypoint',
            [
                'semknoxApiFactory'                => $semknoxApiFactoryMock,
                'libAuthenticationFactory'         => $authFactoryMock,
                'libFeaturesFactory'               => $featuresFactoryMock,
                'libSearchFactory'                 => $searchFactoryMock,
                'libUpdateFactory'                 => $updateFactoryMock,
            ]
        );
    }

    /**
     * @return void
     */
    public function testAuth()
    {
        $this->assertEquals($this->authMock, $this->entrypoint->auth());
    }

    /**
     * @return void
     */
    public function testFeatures()
    {
        $this->assertEquals($this->featureMock, $this->entrypoint->features());
    }

    /**
     * @return void
     */
    public function testSearch()
    {
        $this->assertEquals($this->searchMock, $this->entrypoint->search());
    }

    /**
     * @return void
     */
    public function testUpdate()
    {
        $this->assertEquals($this->updateMock, $this->entrypoint->update());
    }
}
