<?php
/**
 * SEMKNOX API - PHP Library
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Test\Unit\Library;

use Semknox\Semknox\Library\LibUpdate;
use Semknox\Semknox\Library\Semknox\Query\ProductsBatch;
use Semknox\Semknox\Library\Semknox\Query\ProductsDelete;
use Semknox\Semknox\Library\Semknox\Query\ProductsPut;
use Semknox\Semknox\Library\Semknox\SemknoxApi;

class LibUpdateTest extends \PHPUnit\Framework\TestCase
{

    /**
     * @var \PHPUnit_Framework_MockObject_MockObject|SemknoxApi
     */
    protected $semknoxApiMock;

    /**
     * @var LibUpdate
     */
    protected $update;

    /**
     * @var \PHPUnit_Framework_MockObject_MockObject|ProductsPut
     */
    protected $productsPutMock;

    /**
     * @var \PHPUnit_Framework_MockObject_MockObject|ProductsBatch
     */
    protected $productsBatchMock;

    /**
     * @var \PHPUnit_Framework_MockObject_MockObject|ProductsDelete
     */
    protected $deleteProductsMock;

    /**
     * Setup classes
     * @return void
     */
    public function setUp()
    {
        $objectManager = new \Magento\Framework\TestFramework\Unit\Helper\ObjectManager($this);

        $this->productsPutMock = $this->getMockBuilder(
            '\Semknox\Semknox\Library\Semknox\Query\ProductsPut'
        )
            ->disableOriginalConstructor()->getMock();

        $this->productsBatchMock = $this->getMockBuilder(
            '\Semknox\Semknox\Library\Semknox\Query\ProductsBatch'
        )
            ->disableOriginalConstructor()->getMock();

        $this->deleteProductsMock = $this->getMockBuilder(
            '\Semknox\Semknox\Library\Semknox\Query\ProductsDelete'
        )
            ->disableOriginalConstructor()->getMock();

        $this->semknoxApiMock = $this->getMockBuilder('\Semknox\Semknox\Library\Semknox\SemknoxApi')
            ->disableOriginalConstructor()->getMock();

        $this->semknoxApiMock->expects(self::any())
            ->method('putProductsBatch')
            ->willReturn($this->productsBatchMock);

        $this->semknoxApiMock->expects(self::any())
            ->method('putProducts')
            ->willReturn($this->productsPutMock);

        $this->semknoxApiMock->expects(self::any())
            ->method('deleteProducts')
            ->willReturn($this->deleteProductsMock);

        $this->update = $objectManager->getObject(
            '\Semknox\Semknox\Library\LibUpdate',
            [
                'semknoxApi'                => $this->semknoxApiMock
            ]
        );
    }

    /**
     * @return void
     */
    public function testAddProducts()
    {
        $productsArray = random_int(1, 1000);
        $this->productsPutMock->expects(self::once())
            ->method('addProducts')
            ->with($productsArray);
        $this->update->addProducts($productsArray);
    }

    /**
     * @return void
     */
    public function testAddProductsByJson()
    {
        $data = random_int(1, 1000);
        $this->productsPutMock->expects(self::once())
            ->method('addProductsByJson')
            ->with($data);
        $this->update->addProductsByJson($data);
    }

    /**
     * @return void
     */
    public function testReplaceProductsBegin()
    {
        $this->productsBatchMock->expects(self::once())
            ->method('clearInput');
        $this->update->replaceProductsBegin();
    }

    /**
     * @return void
     */
    public function testReplaceProductsAdd()
    {
        $data = random_int(1, 1000);
        $this->productsBatchMock->expects(self::once())
            ->method('batchInput')
            ->with($data);
        $this->update->replaceProductsAdd($data);
    }

    /**
     * @return void
     */
    public function testReplaceProductsAddByJson()
    {
        $data = random_int(1, 1000);
        $this->productsBatchMock->expects(self::once())
            ->method('batchInputByJson')
            ->with($data);
        $this->update->replaceProductsAddByJson($data);
    }

    /**
     * @return void
     */
    public function testReplaceProductsCommit()
    {
        $this->productsBatchMock->expects(self::once())
            ->method('fullUpdate');
        $this->update->replaceProductsCommit();
    }

    /**
     * @return void
     */
    public function testDeleteProduct()
    {
        $data = random_int(1, 1000);
        $this->deleteProductsMock->expects(self::once())
            ->method('delete')
            ->with($data);
        $this->update->deleteProduct($data);
    }
}
