<?php
/**
 * SEMKNOX API - PHP Library
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Test\Unit\Library\Semknox\Test\Query;

use Semknox\Semknox\Library\Semknox\Query\CustomerStatus;

class CustomerStatusTest extends \PHPUnit\Framework\TestCase
{

    /**
     * @var array
     */
    protected $testData;

    /**
     * @var CustomerStatus
     */
    protected $customerStatus;

    /**
     * @var \Semknox\Semknox\Library\Semknox\ApiCommunicator
     */
    protected $apiMock;

    /**
     * Setup classes
     * @return void
     */
    public function setUp()
    {

        $this->testData = [
        'customerName' => 'test',
        'customerId' => 'test2',
        'updateProgress' => 'test3',
        'validThrough' => 'test4',
        ];

        $this->apiMock = $this->getMockBuilder('\Semknox\Semknox\Library\Semknox\ApiCommunicator')
        ->disableOriginalConstructor()
        ->getMock();

        $this->apiMock->expects(self::once())
        ->method('requestGet')
        ->with('customers/:customerId/status')
        ->willReturn($this->testData);

        $this->customerStatus = new CustomerStatus(
            $this->apiMock
        );
    }

    /**
     * @covers \Semknox\Semknox\Library\Semknox\Query\CustomerStatus::getCustomerName
     * @return void
     */
    public function testGetCustomerName()
    {
        $this->assertEquals($this->testData['customerName'], $this->customerStatus->getCustomerName());
    }

    /**
     * @covers \Semknox\Semknox\Library\Semknox\Query\CustomerStatus::getCustomerId
     * @return void
     */
    public function testGetCustomerId()
    {
        $this->assertEquals($this->testData['customerId'], $this->customerStatus->getCustomerId());
    }

    /**
     * @covers \Semknox\Semknox\Library\Semknox\Query\CustomerStatus::getUpdateProgress
     * @return void
     */
    public function testGetUpdateProgress()
    {
        $this->assertEquals($this->testData['updateProgress'], $this->customerStatus->getUpdateProgress());
    }

    /**
     * @covers \Semknox\Semknox\Library\Semknox\Query\CustomerStatus::getValidThrough
     * @return void
     */
    public function testGetValidThrough()
    {
        $this->assertEquals($this->testData['validThrough'], $this->customerStatus->getValidThrough());
    }

    /**
     * @covers \Semknox\Semknox\Library\Semknox\Query\CustomerStatus::testConnection
     * @return void
     */
    public function testTestConnection()
    {
        $this->assertNull(
            $this->customerStatus->testConnection(),
            'Test connection should not return anything, but simply call any other interface method.'
        );
    }

    /**
     * Test if requestGet is only called once.
     * There are no asserts here, see apiMock->expects for details.
     * @return void
     */
    public function testMulti()
    {
        $this->customerStatus->getCustomerName();
        $this->customerStatus->getCustomerId();
        $this->customerStatus->getCustomerName();
    }
}
