<?php
/**
 * SEMKNOX API - PHP Library
 *
 * @copyright   Copyright (c) 2018 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Test\Unit\Library\Semknox\Test\Query;

use Semknox\Semknox\Library\Semknox\Query\ProductsBatch;

class ProductsBatchTest extends \PHPUnit\Framework\TestCase
{

    /**
     * @var array
     */
    protected $testData;

    /**
     * @var ProductsBatch
     */
    protected $productsBatch;

    /**
     * @var \Semknox\Semknox\Library\Semknox\ApiCommunicator|\PHPUnit_Framework_MockObject_MockObject
     */
    protected $apiMock;

    /**
     * @var array
     */
    protected $demoData;

    /**
     * Setup
     * @return void
     */
    public function setUp()
    {

        $this->testData = [
            'customerName' => 'test',
            'customerId' => 'test2',
            'updateProgress' => 'test3',
            'validThrough' => 'test4',
        ];

        $this->apiMock = $this->getMockBuilder('\Semknox\Semknox\Library\Semknox\ApiCommunicator')
            ->disableOriginalConstructor()
            ->getMock();

        $this->demoData = [
            "test" => "is what this is",
            "this is a" => "test"
        ];

        $this->productsBatch = new ProductsBatch(
            $this->apiMock
        );
    }

    /**
     * @return void
     */
    public function testClearInput()
    {
        $this->apiMock->expects(self::once())
            ->method('requestGet')
            ->with('products/clearInput');

        $this->productsBatch->clearInput();
    }

    /**
     * @return void
     */
    public function testBatchInput()
    {
        $this->apiMock->expects(self::once())
            ->method('requestPut')
            ->with('products/batchInput', [
                'productsJsonArray' => urlencode(json_encode($this->demoData))
            ])
            ->willReturn($this->testData);

        $this->productsBatch->batchInput($this->demoData);
    }

    /**
     * @return void
     */
    public function testBatchInputByJson()
    {
        $this->apiMock->expects(self::once())
            ->method('requestPut')
            ->with('products/batchInput', [
                'productsJsonArray' => urlencode(json_encode($this->demoData))
            ])
            ->willReturn($this->testData);

        $this->productsBatch->batchInputByJson(json_encode($this->demoData));
    }

    /**
     * @return void
     */
    public function testFullUpdate()
    {
        $this->apiMock->expects(self::once())
            ->method('requestGet')
            ->with('products/fullUpdate');

        $this->productsBatch->fullUpdate();
    }
}
