<?php
/**
 * SEMKNOX API - PHP Library
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Test\Unit\Library\Semknox\Test\Query;

use Semknox\Semknox\Library\Semknox\Query\ProductsPut;

class ProductsPutTest extends \PHPUnit\Framework\TestCase
{

    /**
     * @var array
     */
    protected $testData;

    /**
     * @var ProductsPut
     */
    protected $productsPut;

    /**
     * @var \Semknox\Semknox\Library\Semknox\ApiCommunicator|\PHPUnit_Framework_MockObject_MockObject
     */
    protected $apiMock;

    /**
     * @var array
     */
    protected $demoData;

    /**
     * Setup
     * @return void
     */
    public function setUp()
    {

        $this->testData = [
        'customerName' => 'test',
        'customerId' => 'test2',
        'updateProgress' => 'test3',
        'validThrough' => 'test4',
        ];

        $this->apiMock = $this->getMockBuilder('\Semknox\Semknox\Library\Semknox\ApiCommunicator')
        ->disableOriginalConstructor()
        ->getMock();

        $this->demoData = [
        "test" => "is what this is",
        "this is a" => "test"
        ];

        $this->productsPut = new ProductsPut(
            $this->apiMock
        );
    }

    /**
     * @return void
     */
    public function testAddProducts()
    {

        $this->apiMock->expects(self::once())
        ->method('requestPut')
        ->with('products', [
        'full' => 'false',
        'productsJsonArray' => urlencode(json_encode($this->demoData))
        ])
        ->willReturn($this->testData);

        $this->productsPut->addProducts($this->demoData);
    }

    /**
     * @return void
     */
    public function testReplaceAllProductsProducts()
    {

        $this->apiMock->expects(self::once())
        ->method('requestPut')
        ->with('products', [
        'full' => 'true',
        'productsJsonArray' => urlencode(json_encode($this->demoData))
        ])
        ->willReturn($this->testData);

        $this->productsPut->replaceAllProducts($this->demoData);
    }

    /**
     * @return void
     */
    public function testAddProductsByJson()
    {

        $this->apiMock->expects(self::once())
        ->method('requestPut')
        ->with('products', [
        'full' => 'false',
        'productsJsonArray' => urlencode(json_encode($this->demoData))
        ])
        ->willReturn($this->testData);

        $this->productsPut->addProductsByJson(json_encode($this->demoData));
    }

    /**
     * @return void
     */
    public function testReplaceAllProductsProductsByJson()
    {

        $this->apiMock->expects(self::once())
        ->method('requestPut')
        ->with('products', [
        'full' => 'true',
        'productsJsonArray' => urlencode(json_encode($this->demoData))
        ])
        ->willReturn($this->testData);

        $this->productsPut->replaceAllProductsByJson(json_encode($this->demoData));
    }
}
