<?php
/**
 * SEMKNOX API - PHP Library
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http =>//www.tudock.de)
 * @author      Artsiom Bruneuski <artsiom.bruneuski@tudock.de>
 */

// @codingStandardsIgnoreFile

namespace Semknox\Semknox\Test\Unit\Library\Semknox\Test\Query;

use Magento\Framework\TestFramework\Unit\Helper\ObjectManager as ObjectManagerHelper;

/**
 * Product Test
 *
 * @SuppressWarnings(PHPMD.CouplingBetweenObjects)
 * @SuppressWarnings(PHPMD.TooManyFields)
 * @SuppressWarnings(PHPMD.ExcessivePublicCount)
 *
 */
class ProductsTest extends \PHPUnit\Framework\TestCase
{
    /**
     * @var \Semknox\Semknox\Library\Semknox\ApiCommunicator|\PHPUnit_Framework_MockObject_MockObject
     */
    protected $apiMock;

    protected $objectManagerHelper;

    public function setUp()
    {
        $this->objectManagerHelper = new ObjectManagerHelper($this);

        $this->apiMock = $this->getMockBuilder('\Semknox\Semknox\Library\Semknox\ApiCommunicator')
            ->disableOriginalConstructor()
            ->getMock();
    }

    /**
     * @dataProvider getSearchResultsDataProvider
     */
    public function testSearchResults($query, $response, $result)
    {
        // TODO: FIX TEST
        $this->markTestIncomplete("Does not work currently and needs to be fixed!");

        $this->apiMock->method('requestGet')
            ->with('products', [
                'query' => $query,
                'limit' => 10000
            ])
            ->willReturn($response);

        /** @var \Semknox\Semknox\Library\Semknox\Query\Products  $products */
        $products = $this->objectManagerHelper->getObject(
            'Semknox\Semknox\Library\Semknox\Query\Products',
            [
                'apiCommunicator' => $this->apiMock,
                'query' => $query
            ]
        );

        $this->assertEquals($result, count($products->getResults()));
    }

    /**
     * @dataProvider getZeroResultsDataProvider
     */
    public function testZeroResults($query, $response, $result)
    {
        // TODO: FIX TEST
        $this->markTestIncomplete("Does not work currently and needs to be fixed!");

        $this->apiMock->method('requestGet')
            ->with('products', [
                'query' => $query,
                'limit' => 10000
            ])
            ->willReturn($response);

        /** @var \Semknox\Semknox\Library\Semknox\Query\Products  $products */
        $products = $this->objectManagerHelper->getObject(
            'Semknox\Semknox\Library\Semknox\Query\Products',
            [
                'apiCommunicator' => $this->apiMock,
                'query' => $query
            ]
        );

        $this->assertEquals($result, count($products->getZeroResults()));
    }

    public function testNoResults()
    {
        // TODO: FIX TEST
        $this->markTestIncomplete("Does not work currently and needs to be fixed!");

        /** @var \Semknox\Semknox\Library\Semknox\Query\Products  $products */
        $products = $this->objectManagerHelper->getObject(
            'Semknox\Semknox\Library\Semknox\Query\Products',
            [
                'apiCommunicator' => $this->apiMock,
                'query' => 'test'
            ]
        );

        $this->assertNull($products->getResults());
    }

    public function testNoQuery()
    {
        /** @var \Semknox\Semknox\Library\Semknox\Query\Products  $products */
        $products = $this->objectManagerHelper->getObject(
            'Semknox\Semknox\Library\Semknox\Query\Products',
            [
                'apiCommunicator' => $this->apiMock
            ]
        );

        $this->assertNull($products->getResults());
    }

    public function getSearchResultsDataProvider()
    {
        return [
            [
                'query' => 'test query 1',
                'response' => [
                    'searchResults' => [
                        [

                        ]
                    ]
                ],
                'result' => 0
            ],
            [
                'query' => 'test query 1',
                'response' => [
                    'searchResults' => [
                    ]
                ],
                'result' => 0
            ],
            [
                'query' => 'test query 1',
                'response' => [
                    'searchResults' => [
                        [
                            [
                                "id" => 1,
                                "groupId" => "1",
                                "articleNumber" => "1",
                                "properties" => [],
                                "passOn" => [],
                                "name" => "Test 2",
                                "image" => "image2.jpg",
                                "link" => "link2.html",
                                "featured" => false,
                                "head" => true
                            ]
                        ]
                    ]
                ],
                'result' => 1
            ],
            [
                'query' => 'test query 2',
                'response' => [
                    'searchResults' => [
                        [
                            [
                                "id" => 1,
                                "groupId" => "1",
                                "articleNumber" => "1",
                                "properties" => [],
                                "passOn" => [],
                                "name" => "Test 2",
                                "image" => "image2.jpg",
                                "link" => "link2.html",
                                "featured" => false,
                                "head" => true
                            ],
                            [
                                "id" => 1,
                                "groupId" => "1",
                                "articleNumber" => "1",
                                "properties" => [],
                                "passOn" => [],
                                "name" => "Test 2",
                                "image" => "image2.jpg",
                                "link" => "link2.html",
                                "featured" => false,
                                "head" => true
                            ]
                        ]
                    ]
                ],
                'result' => 2
            ]
        ];
    }

    public function getZeroResultsDataProvider()
    {
        return [
            [
                'query' => 'test query 1',
                'response' => [
                    'zeroResults' => [
                    ]
                ],
                'result' => 0
            ],
            [
                'query' => 'test query 1',
                'response' => [
                    'zeroResults' => [
                        [
                            "id" => 1,
                            "groupId" => "1",
                            "articleNumber" => "1",
                            "properties" => [],
                            "passOn" => [],
                            "name" => "Test 2",
                            "image" => "image2.jpg",
                            "link" => "link2.html",
                            "featured" => false,
                            "head" => true
                        ]
                    ]
                ],
                'result' => 1
            ],
            [
                'query' => 'test query 2',
                'response' => [
                    'zeroResults' => [

                        [
                            "id" => 1,
                            "groupId" => "1",
                            "articleNumber" => "1",
                            "properties" => [],
                            "passOn" => [],
                            "name" => "Test 2",
                            "image" => "image2.jpg",
                            "link" => "link2.html",
                            "featured" => false,
                            "head" => true
                        ],
                        [
                            "id" => 1,
                            "groupId" => "1",
                            "articleNumber" => "1",
                            "properties" => [],
                            "passOn" => [],
                            "name" => "Test 2",
                            "image" => "image2.jpg",
                            "link" => "link2.html",
                            "featured" => false,
                            "head" => true
                        ]

                    ]
                ],
                'result' => 2
            ]
        ];
    }
}