<?php
/**
 * SEMKNOX API - PHP Library
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Marco Köpcke <marco.koepcke@tudock.de>
 */
namespace Semknox\Semknox\Test\Unit\Library\Semknox\Test;

use Semknox\Semknox\Library\Semknox\Query\CustomerStatus;
use Semknox\Semknox\Library\Semknox\Query\ProductsPut;
use Semknox\Semknox\Library\Semknox\SemknoxApi;

class SemknoxApiTest extends \PHPUnit\Framework\TestCase
{

    /**
     * @var SemknoxApi
     */
    protected $semknoxApi;

    /**
     * @var CustomerStatus
     */
    protected $customerStatusMock;

    /**
     * @var ProductsPut
     */
    protected $productsPutMock;

    /**
     * setUp also does CONSTRUCTOR TESTING!
     *
     * NOTES ON CONSTRUCTOR TESTING FOR SemknoxApi:
     * (1) The ApiCommunicatorFactory create Method has to be
     *     called with the provided UserCredentials object (first parameter)
     * (2) All the Query Object Factories have to be called
     *     with the ApiCommunicator returned by the factory from (1) as parameter.
     *
     * @return void
     */
    public function setUp()
    {
        // TODO: FIX TEST
        $this->markTestIncomplete("Does not work currently and needs to be fixed!");

        $userCredentialsMock = $this->getMockBuilder('\Semknox\Semknox\Library\UserCredentials')
        ->disableOriginalConstructor()
        ->getMock();
        $customerId = -123;
        $apiKey = 'test';
        $userCredentialsMock->expects(self::any())->method('getCustomerId')->willReturn($customerId);
        $userCredentialsMock->expects(self::any())->method('getApiKey')->willReturn($apiKey);

        $apiCommunicatorMock = $this->getMockBuilder('\Semknox\Semknox\Library\Semknox\ApiCommunicator')
            ->disableOriginalConstructor()->getMock();

        $this->customerStatusMock = $this->getMock('\Semknox\Semknox\Library\Semknox\Query\CustomerStatus');

        // (1)
        $apiCommunicatorFactoryMock = $this->getMock('\Semknox\Semknox\Library\Semknox\ApiCommunicatorFactory');
        $apiCommunicatorFactoryMock->expects(self::any())
        ->method('create')
        ->with($userCredentialsMock)
        ->will($this->returnValue($apiCommunicatorMock));

        // (2)
        $customerStatusFactoryMock = $this->getMock('\Semknox\Semknox\Library\Semknox\Query\CustomerStatusFactory');
        $customerStatusFactoryMock->expects(self::any())
        ->method('create')
        ->with($apiCommunicatorMock)
        ->will($this->returnValue($this->customerStatusMock));

        // (4)
        $productsPutMock = $this->getMock('\Semknox\Semknox\Library\Semknox\Query\ProductsPutFactory');
        $productsPutMock->expects(self::any())
        ->method('create')
        ->with($apiCommunicatorMock)
        ->will($this->returnValue($this->productsPutMock));

        $this->semknoxApi = new SemknoxApi(
            $userCredentialsMock,
            $apiCommunicatorFactoryMock,
            $customerStatusFactoryMock,
            $productsPutMock
        );
    }

    /**
     * @covers \Semknox\Semknox\Library\SemknoxApi::getCustomerStatus
     *
     * @return void
     */
    public function testGetCustomerStatus()
    {
        $this->assertEquals(
            $this->customerStatusMock,
            $this->semknoxApi->getCustomerStatus(),
            'The API has to return the customer status object from the factory'
        );
    }

    /**
     * @covers \Semknox\Semknox\Library\SemknoxApi::putProducts
     *
     * @return void
     */
    public function testPutProducts()
    {
        $this->assertEquals(
            $this->productsPutMock,
            $this->semknoxApi->putProducts(),
            'The API has to return the put products object from the factory'
        );
    }
}
