/**
 * SEMKNOX Magento 2 Module
 *
 * @copyright   Copyright (c) 2017 Tudock GmbH (http://www.tudock.de)
 * @author      Artsiom Bruneuski <artsiom.bruneuski@tudock.de>
 */
define([
    'jquery',
    'mage/translate',
    'matchMedia',
    'jquery-ui'
], function ($, $t, mediaCheck) {
    'use strict';

    $.widget('mage.tudockAutocomplete', $.ui.autocomplete, {
        options: {
            submitBtn: 'button[type="submit"]',
            searchLabel: '[data-role=minisearch-label]',
            isMobile: null,
            position: {
                my: "left+0 top+10",
            },
        },
        items: [],
        _create: function() {
            this.searchForm = $(this.options.formSelector);
            this.submitBtn = this.searchForm.find(this.options.submitBtn)[0];
            this.searchLabel = $(this.options.searchLabel);
            mediaCheck({
                media: '(max-width: 768px)',
                entry: function () {
                    this.isMobile = true;
                }.bind(this),
                exit: function () {
                    this.isMobile = false;
                    this.element.removeAttr('aria-expanded');
                }.bind(this)
            });

            this.searchLabel.on('click', function (e) {
                // allow input to lose its' focus when clicking on label
                if (this.isMobile && this.isActive()) {
                    e.preventDefault();
                }
            }.bind(this));

            this.element.on('focus', this.setActiveState.bind(this, true));
            $( window ).resize(this._resizeMenu.bind(this));

            this._on( this.element, {
                    keydown: function (event) {
                        var keyCode = $.ui.keyCode;
                        switch ( event.keyCode ) {
                            case keyCode.LEFT:
                                this._move( "previousPage", event );
                                this.element.prop( "readOnly", true );
                            break;
                            case keyCode.RIGHT:
                                this._move( "nextPage", event );
                                this.element.prop( "readOnly", true );
                            break;
                            default:
                                this.element.prop( "readOnly", false);
                                break;
                        }
                    }
                }
            );

            var ret =  this._super();

            this.menu.options.items = '*.semknox-suggest-item';

            this.menu.focus = this.menuEvents.focus.bind(this.menu);
            this.menu.previous = this.menuEvents.previous.bind(this.menu);
            this.menu.next = this.menuEvents.next.bind(this.menu);
            this.menu.isFirstItem = this.menuEvents.isFirstItem.bind(this.menu);
            this.menu.isLastItem = this.menuEvents.isLastItem.bind(this.menu);
            this.menu.nextPage = this.menuEvents.nextPage.bind(this.menu);
            this.menu.element.on('menuselect', this.menuselect.bind(this));

            return ret;
        },
        menuselect: function (event, ui) {

            var item = ui.item.data( "ui-autocomplete-item" );
            if (item) {
                this.element.val(item.name);

                var link = ui.item.find('a');

                if (link && link.attr('href') && link.attr('href') != '#') {
                    var url = link.attr('href');
                    document.location.href = url;
                } else {
                    this.searchForm.submit();
                }
            }
        },
        /**
         * Sets state of the search field to provided value.
         *
         * @param {Boolean} isActive
         */
        setActiveState: function (isActive) {
            this.searchLabel.toggleClass('active', isActive);

            if (this.isMobile) {
                this.element.attr('aria-expanded', isActive);
            }
        },
        /**
         * Checks if search field is active.
         *
         * @returns {Boolean}
         */
        isActive: function () {
            return this.searchLabel.hasClass('active');
        },
        _initSource: function() {
            var array, url,
                that = this;
            if ( $.isArray(this.options.source) ) {
                array = this.options.source;
                this.source = function( request, response ) {
                    response( $.ui.autocomplete.filter( array, request.term ) );
                };
            } else if ( typeof this.options.source === "string" ) {
                url = this.options.source;

                var data = {
                    limitSearch: 3,
                    limitCategory: 3,
                    limitProduct: 5,
                    language: 'de',
                    query: '',
                }

                // Add additional fields of library to request
                for (var key in this.options.additional) {
                    data[key] = this.options.additional[key];
                }

                this.source = function( request, response ) {
                    data.query = request.term;

                    if ( that.xhr ) {
                        that.xhr.abort();
                    }
                    that.xhr = $.ajax({
                        url: url,
                        data: data,
                        dataType: "json",
                        success: function( data ) {
                            response( data );
                        },
                        error: function() {
                            response( [] );
                        }
                    });
                };
            } else {
                this.source = this.options.source;
            }
        },
        /**
         * Render columns with categories, search terms and brands
         * @param ul
         * @returns {*|jQuery|HTMLElement}
         * @private
         */
        _renderFirst: function (ul) {
            var firstContainer = $( "<div>" );
            $('<li>').addClass('semknox-first')
                .append( firstContainer )
                .appendTo( ul )
                .data('ui-autocomplete-item', {});
            return firstContainer;
        },
        /**
         * Render columns with products
         * @param ul
         * @returns {*|jQuery|HTMLElement}
         * @private
         */
        _renderSecond: function (ul) {
            var secondContainer = $( "<div>" );
            $('<li>').addClass('semknox-second')
                .append( secondContainer )
                .appendTo( ul )
                .data('ui-autocomplete-item', {});

            return secondContainer;
        },
        _renderShowAll: function (ul) {
            var container = $( "<button>" ).text( $t('SKNOX_Show All') );

            $('<li>').addClass('semknox-show-all')
                .append( container )
                .appendTo( ul )
                .data('ui-autocomplete-item', {});

            return container;
        },
        _highlight: function(data){
            var words = this.element.val().trim().split(' ');
            var reg = new RegExp('(' +words.join('|') + ')', "ig");

            if (data) {
                data = data.replace(reg, "<span class=semknox-highlight>$1</span>");
            }
            return data;
        },
        _renderSearchTerms: function(container, items){
            var that = this;

            var searchTermsContainer = $('<div>')
                .addClass('semknox-searchterms-container')
                .appendTo( container )
                .hide();

            $('<div>').addClass('semknox-label')
                .append( $t('SKNOX_Search Terms') )
                .appendTo( searchTermsContainer );

            $.each( items, function( index, item ) {
                that._renderSearchTerm(searchTermsContainer, item);
                searchTermsContainer.show();
            });
        },
        _renderCategories: function(container, items){
            var that = this, limit = null;
            if (this.isMobile){
                limit = 2;
            }
            var categoriesContainer = $('<div>')
                .addClass('semknox-categories-container')
                .appendTo( container )
                .hide();

            $('<div>').addClass('semknox-label')
                .append( $t('SKNOX_Categories') )
                .appendTo( categoriesContainer );

            var inx = 0;
            $.each( items, function( index, item ) {
                if (limit === null || inx < limit) {
                    that._renderCategory(categoriesContainer, item);
                    categoriesContainer.show();
                }
                inx++;
            });
        },
        _renderProducts: function (container, items) {
            var that = this, limit = null;
            if (this.isMobile){
                limit = 2;
            }
            var productsContainer = $('<div>')
                .addClass('semknox-products-container')
                .appendTo( container );

            $('<div>').addClass('semknox-label')
                .append( $t('SKNOX_Products') )
                .appendTo( productsContainer );

            var inx = 0;
            $.each( items, function( index, item ) {
                if (limit === null || inx < limit) {
                    that._renderProduct(productsContainer, item);
                    inx++;
                }
            });
        },
        /**
         * Build container with two columns
         * @param ul
         * @param items
         * @private
         */
        _renderMenu: function( ul, items ) {
            var that = this;

            var suggests = items[1];

            if (suggests && typeof(suggests) === 'object' && suggests.Produkte.length > 0) {
                var firstContainer = this._renderFirst(ul);
                var secondContainer = this._renderSecond(ul);
                var showAllContainer = this._renderShowAll(ul);

                if (this.isMobile) {
                    this._renderProducts(firstContainer, suggests.Produkte);
                    this._renderCategories(secondContainer, suggests.Kategorien);
                    this._renderSearchTerms(secondContainer, suggests.Suchvorschläge);
                } else {
                    this._renderCategories(firstContainer, suggests.Kategorien);
                    this._renderSearchTerms(firstContainer, suggests.Suchvorschläge);
                    this._renderProducts(secondContainer, suggests.Produkte);
                }

                this._on(ul.find('.semknox-suggest-item'), {
                    hover: this._onSubMenuHover
                });

                this._on(showAllContainer, {
                    click: function () {
                        this.searchForm.submit();
                    }.bind(this)
                });
            } else {
                this.menu.element.hide();
            }

            this.items = items;
        },
        /**
         * Workaround to handle default autocomplete menufocus event
         * @param event
         * @private
         */
        _onSubMenuHover: function (event) {
            var item = $(event.srcElement).closest('.semknox-suggest-item').data('ui-autocomplete-item');
            $(event.srcElement).closest('li.semknox-second.ui-menu-item').data('ui-autocomplete-item', item);
        },
        /**
         * Render categories column
         * @param div
         * @param item
         * @returns {*|jQuery}
         * @private
         */
        _renderCategory: function( div, item ) {
            var link  = $('<a>')
                .addClass('semknox-suggest-category')
                .append($('<span>').addClass('semknox-item-value').html(this._highlight(item.name)))
                .append( $( "<div>" ).addClass('semknox-item-label').text( $t('SKNOX_Category') ) )
                .attr("href", item.link ? item.link : '#');

            return $( "<div>" )
                .addClass('semknox-suggest-item')
                .append( link )
                .appendTo( div )
                .data( "ui-autocomplete-item", item );
        },
        _renderSearchTerm: function( div, item ) {
            var link  = $('<a>')
                .addClass('semknox-suggest-searchterm')
                .append($('<span>').addClass('semknox-item-value').html(this._highlight(item.name)))
                .append( $( "<div>" ).addClass('semknox-item-label').text( $t('SKNOX_Search Term')) )
                .attr("href", item.link ? item.link : '#');

            return $( "<div>" )
                .addClass('semknox-suggest-item')
                .append( link )
                .appendTo( div )
                .data( "ui-autocomplete-item", item );
        },
        /**
         * Render product column
         * @param div
         * @param item
         * @returns {*|jQuery}
         * @private
         */
        _renderProduct: function( div, item ) {
            var value = $('<div>').addClass('semknox-item-value')
                .append($('<div>').html(this._highlight(item.name)));

            if (item.price){
                var prefix = "";
                if (item.typeId && item.typeId === 'configurable') {
                    prefix = $t('SKNOX_from') + ' ';
                }
                value.append($('<div>').addClass('semknox-price').html(prefix + item.price + ' ' + item.price_currency));
            }

            var link  = $('<a>')
                    .addClass('semknox-suggest-product')
                    .append($('<img>').attr("src", item.image))
                    .append(value)
                    .append( $( "<div>" ).addClass('semknox-item-label').text( $t('SKNOX_Product') ) )
                    .attr("href", item.link);

            return $( "<div>" )
                .addClass('semknox-suggest-item')
                .append( link )
                .appendTo( div )
                .data( "ui-autocomplete-item", item );
        },
        /**
         * Rewrite default resize to calculate default position of popup
         * @private
         */
        _resizeMenu: function () {
            var ul = this.menu.element;

            ul.empty();
            this._renderMenu(ul, this.items);
            this.menu.refresh();

            ul.outerWidth(this.element.outerWidth());
            ul.resizable();

            ul.position( $.extend( {
                of: this.element
            }, this.options.position ) );
        },
        /**
         * Use flex container instead of block
         * @param items
         * @private
         */
        _suggest: function( items ) {
            var ul = this.menu.element.empty();
            this._renderMenu( ul, items );
            this.isNewMenu = true;
            this.menu.refresh();

            // Size and position menu
            ul.css({'display': 'flex'})
            this._resizeMenu();
            ul.position( $.extend( {
                of: this.element
            }, this.options.position ) );

            if ( this.options.autoFocus ) {
                this.menu.next();
            }

            // Listen for interactions outside of the widget (#6642)
            this._on( this.document, {
                mousedown: "_closeOnClickOutside"
            } );
        },
        _move: function( direction, event ) {
            if ((this.menu.isFirstItem() && direction == 'previous')
                || (this.menu.isLastItem() && direction == 'next')) {

                this.menu.blur();
            }
            this.menu[ direction ]( event );

            if (this.menu.active) {
                var item = this.menu.active.data("ui-autocomplete-item");
                this.element.val( item.name );
            }
        },

        menuEvents: {
            focus: function( event, item ) {
                var nested, focused, activeParent;
                this.blur( event, event && event.type === "focus" );

                this._scrollIntoView( item );

                this.active = item.first();

                focused = this.active.children( ".ui-menu-item-wrapper" );
                this._addClass( focused, null, "ui-state-active" );

                // Only update aria-activedescendant if there's a role
                // otherwise we assume focus is managed elsewhere
                if ( this.options.role ) {
                    this.element.attr( "aria-activedescendant", focused.attr( "id" ) );
                }

                // Highlight active parent menu item, if any
                activeParent = this.active
                    .parent()
                    .closest( ".ui-menu-item" )
                    .children( ".ui-menu-item-wrapper" );
                this._addClass( activeParent, null, "ui-state-active" );

                if ( event && event.type === "keydown" ) {
                    this._close();
                } else {
                    this.timer = this._delay( function() {
                        this._close();
                    }, this.delay );
                }

                nested = item.children( ".ui-menu" );
                if ( nested.length && event && ( /^mouse/.test( event.type ) ) ) {
                    this._startOpening( nested );
                }
                // this.activeMenu = item.parent();

                this._trigger( "focus", event, { item: item } );
            },
            next: function( event ) {
                if ( this.active ) {
                    var all = this.active.closest('.ui-autocomplete').find(".ui-menu-item");
                    var next = all.slice(all.index(this.active) + 1).eq(0);
                    if (next.length > 0) {
                        this.focus(event, next);
                    }
                } else {
                    this._move("next", "first", event);
                }
            },

            previous: function( event ) {
                if ( this.active ) {
                    var all = this.active.closest('.ui-autocomplete').find(".ui-menu-item");
                    var sliced = all.slice(0, all.index(this.active));
                    var next = sliced.eq(sliced.length - 1);
                    if (next.length > 0) {
                        this.focus(event, next);
                    }
                } else {
                    this._move( "prev", "last", event );
                }
            },

            isFirstItem: function() {
                var ret = false;
                if (this.active) {
                    var all = this.active.closest('.ui-autocomplete').find(".ui-menu-item");
                    var sliced = all.slice(0, all.index(this.active));
                    return sliced.length === 0;
                }
                return ret;
            },

            isLastItem: function() {
                var ret = false;
                if (this.active) {
                    var all = this.active.closest('.ui-autocomplete').find(".ui-menu-item");
                    var sliced = all.slice(all.index(this.active) + 1);
                    return sliced.length === 0;
                }
                return ret;
            },
            nextPage: function( event ) {
                var item, base, height;

                if ( !this.active ) {
                    this.next( event );
                    return;
                }
                if ( this.isLastItem() ) {
                    return;
                }
                if ( this._hasScroll() ) {
                    base = this.active.offset().top;
                    height = this.element.height();
                    this.active.nextAll( ".ui-menu-item" ).each( function() {
                        item = $( this );
                        return item.offset().top - base - height < 0;
                    } );

                    this.focus( event, item );
                } else {
                    var element = this.activeMenu.find( this.options.items )
                        [ !this.active ? "first" : "last" ]();

                    if (element) {
                        var active = element.closest('.semknox-products-container').find(".ui-menu-item");
                        this.focus(event, active);
                    }
                }
            },
        }

    });

    return $.mage.tudockAutocomplete;
});