define([
    'jquery'
], function($) {
    /**
     * A singleton object manipulating the miniform search to transform the search URL info the configured SEO urls,
     * if enabled.
     */
    var tudockSeo = {
        config: {
            enabled: false,
            prefix: null,
            baseUrl: null
        },
        formHandler: undefined,

        isEnabled: function() {
            return this.config.enabled == '1';
        },

        /**
         * Initialize and set config
         * @param config
         */
        init: function(config) {
            this.config = config;

            var self = this;
            $(document).on('submit', '#search_mini_form', function(event) {
                if (self.isEnabled()) {
                    // Manually create the URL, if SEO URLs are enabled.
                    var formData = $(event.target).serializeArray(),
                        queryString = '';
                    for (var i = 0; i < formData.length; i++) {
                        if (formData[i]["name"] == "q") {
                            queryString = formData[i]["value"];
                        }
                    }
                    return self.formHandler(event, true, self.buildUrl(queryString));
                }
                return self.formHandler(event, false);
            });

        },

        buildUrl: function(queryString) {
            return this.config.baseUrl + this.config.prefix + '-' + encodeURIComponent(queryString.replace(' ','-'));
        },

        /**
         * Register as a form handler on the miniform submit
         */
        registerFormHandler: function(handlerFunction) {
            this.formHandler = handlerFunction;
        },

        /**
         * Default, non-pjax, search box handler
         *
         * @param event         jQuery form submit event
         * @param wasSeoUsed    Was a SEO url created?
         * @param seoUrl        ...if yes redirect to this URL instead of submitting the form
         * @returns {boolean}   Should the form be submitted?
         */
        defaultHandler: function(event, wasSeoUsed, seoUrl) {
            if (wasSeoUsed) {
                location.href = seoUrl;
                return false;
            }
            return true;
        }
    };

    tudockSeo.registerFormHandler(tudockSeo.defaultHandler);
    return tudockSeo;
});